"""specimens views."""

from django.http import Http404
from drf_spectacular.utils import extend_schema
from rest_framework import status
from rest_framework.permissions import AllowAny
from rest_framework.response import Response
from rest_framework.views import APIView

from dfhir.specimens.models import Specimen
from dfhir.specimens.serializers import SpecimenSerializer


class SpecimenListView(APIView):
    """Specimen list view."""

    permission_classes = [AllowAny]

    @extend_schema(responses={200: SpecimenSerializer(many=True)})
    def get(self, request):
        """Get specimens."""
        specimens = Specimen.objects.all()
        serializer = SpecimenSerializer(specimens, many=True)
        return Response(serializer.data, status=status.HTTP_200_OK)

    @extend_schema(request=SpecimenSerializer, responses={201: SpecimenSerializer})
    def post(self, request):
        """Create a new specimen."""
        serializer = SpecimenSerializer(data=request.data)
        serializer.is_valid(raise_exception=True)
        serializer.save()
        return Response(serializer.data, status=status.HTTP_201_CREATED)


class SpecimenDetailView(APIView):
    """specimen detail view."""

    permission_classes = [AllowAny]

    def get_object(self, pk):
        """Get specimen object."""
        try:
            return Specimen.objects.get(pk=pk)
        except Specimen.DoesNotExist as err:
            raise Http404 from err

    @extend_schema(responses={200: SpecimenSerializer})
    def get(self, request, pk=None):
        """Get specimen."""
        specimen = self.get_object(pk)
        serializer = SpecimenSerializer(specimen)
        return Response(serializer.data, status=status.HTTP_200_OK)

    @extend_schema(request=SpecimenSerializer, responses={200: SpecimenSerializer})
    def patch(self, request, pk=None):
        """Update specimen."""
        specimen = self.get_object(pk)
        serializer = SpecimenSerializer(specimen, data=request.data, partial=True)
        serializer.is_valid(raise_exception=True)
        serializer.save()
        return Response(serializer.data, status=status.HTTP_200_OK)

    @extend_schema(responses={204: None})
    def delete(self, request, pk=None):
        """Delete specimen."""
        specimen = self.get_object(pk)
        specimen.delete()
        return Response(status=status.HTTP_204_NO_CONTENT)



"""Location models."""

from django.contrib.postgres.fields import ArrayField
from django.db import models

from dfhir.base.models import (
    Address,
    Availability,
    BaseReference,
    CodeableConcept,
    Coding,
    ExtendedContactDetail,
    Identifier,
    OrganizationReference,
    TimeStampedModel,
    VirtualServiceDetails,
)
from dfhir.endpoints.models import EndpointReference

from .choices import (
    LocationMode,
    LocationStatus,
)


class Position(TimeStampedModel):
    """Position model."""

    longitude = models.FloatField()
    latitude = models.FloatField()
    altitude = models.FloatField(null=True)

    def __str__(self):
        """Return position as string representation."""
        return f"{self.longitude}, {self.latitude}"


class LocationReference(BaseReference):
    """Location Reference model."""

    identifier = models.ForeignKey(
        Identifier,
        on_delete=models.DO_NOTHING,
        null=True,
        related_name="location_reference_identifier",
    )
    location = models.ForeignKey(
        "Location",
        on_delete=models.DO_NOTHING,
        related_name="location_reference",
        null=True,
    )


class LocationOrganizationReference(BaseReference):
    """Location Organization Reference model."""

    identifier = models.ForeignKey(
        Identifier,
        on_delete=models.DO_NOTHING,
        null=True,
        related_name="location_organization_reference_identifier",
    )
    organization = models.ForeignKey(
        "organizations.Organization",
        on_delete=models.DO_NOTHING,
        related_name="location_organization_reference",
        null=True,
    )
    location = models.ForeignKey(
        "Location",
        on_delete=models.DO_NOTHING,
        related_name="location_organization_reference",
        null=True,
    )


class Location(TimeStampedModel):
    """Location model."""

    identifier = models.ManyToManyField(
        Identifier, related_name="location_identifier", blank=True
    )
    name = models.CharField(max_length=255)
    status = models.CharField(
        choices=LocationStatus.choices, max_length=255, default=LocationStatus.ACTIVE
    )
    operational_status = models.ForeignKey(
        Coding,
        on_delete=models.DO_NOTHING,
        null=True,
        related_name="location_operational_status",
    )
    alias = ArrayField(models.CharField(max_length=255), null=True)
    description = models.TextField(null=True)
    mode = models.CharField(choices=LocationMode.choices, max_length=255, null=True)
    address = models.ForeignKey(Address, on_delete=models.DO_NOTHING, null=True)
    form = models.ForeignKey(
        CodeableConcept,
        on_delete=models.DO_NOTHING,
        null=True,
        related_name="location_form",
    )
    position = models.ForeignKey(Position, on_delete=models.DO_NOTHING, null=True)
    managing_organization = models.ForeignKey(
        OrganizationReference,
        on_delete=models.DO_NOTHING,
        related_name="location_organization",
        null=True,
    )
    part_of = models.ForeignKey(
        LocationReference,
        on_delete=models.DO_NOTHING,
        null=True,
        blank=True,
        related_name="location_part_of",
    )
    hours_of_operation = models.ForeignKey(
        Availability, on_delete=models.DO_NOTHING, null=True
    )
    type = models.ManyToManyField(
        CodeableConcept, related_name="location_type", blank=True
    )
    characteristic = models.ManyToManyField(
        CodeableConcept, related_name="location_characteristic", blank=True
    )
    contact = models.ManyToManyField(
        ExtendedContactDetail, related_name="location_contact", blank=True
    )
    endpoint = models.ManyToManyField(
        EndpointReference, related_name="location_endpoint", blank=True
    )
    virtual_service_details = models.ManyToManyField(
        VirtualServiceDetails,
        related_name="location_virtual_service_details",
        blank=True,
    )

    def __str__(self):
        """Return name as string representation."""
        return self.name


class LocationCodeableReference(TimeStampedModel):
    """Location Codeable Reference model."""

    concept = models.ForeignKey(
        CodeableConcept,
        on_delete=models.SET_NULL,
        null=True,
        related_name="location_codeable_reference_concept",
    )
    reference = models.ForeignKey(
        LocationReference,
        on_delete=models.SET_NULL,
        null=True,
        related_name="location_codeable_reference_reference",
    )



"""Substances urls."""

from django.urls import path

from . import views

app_name = "substances"

urlpatterns = [
    path("substances/", views.SubstanceListView.as_view()),
    path("substances/<int:pk>/", views.SubstanceDetailView.as_view()),
]



"""nutrition intakes models."""

from django.db import models

from dfhir.base.models import (
    BaseReference,
    CodeableConcept,
    Identifier,
    Reference,
    TimeStampedModel,
)
from dfhir.nutritionintakes.choices import NutritionIntakeStatusChoices
from dfhir.substances.models import SubstanceCodeableReference


class NutritionIntakeBasedOnReference(BaseReference):
    """Nutrition intake based on reference model."""

    identifier = models.ForeignKey(
        Identifier,
        on_delete=models.DO_NOTHING,
        null=True,
        related_name="nutrition_intake_based_on_reference_identifier",
    )
    # TODO: nutrition_order = models.ForeignKey("NutritionOrder", on_delete=models.DO_NOTHING, null=True)
    care_plan = models.ForeignKey(
        "careplans.CarePlan",
        on_delete=models.DO_NOTHING,
        null=True,
        related_name="nutrition_intake_based_on_reference_care_plan",
    )
    service_request = models.ForeignKey(
        "servicerequests.ServiceRequest",
        on_delete=models.DO_NOTHING,
        null=True,
        related_name="nutrition_intake_based_on_reference_service_request",
    )


class NutritionIntakePartOfReference(BaseReference):
    """Nutrition intake part of reference model."""

    identifier = models.ForeignKey(
        Identifier,
        on_delete=models.DO_NOTHING,
        null=True,
        related_name="nutrition_intake_part_of_reference_identifier",
    )
    nutrition_intake = models.ForeignKey(
        "NutritionIntake",
        on_delete=models.DO_NOTHING,
        null=True,
        related_name="nutrition_intake_part_of_reference_nutrition_intake",
    )
    procedure = models.ForeignKey(
        "procedures.Procedure",
        on_delete=models.DO_NOTHING,
        null=True,
        related_name="nutrition_intake_part_of_reference_procedure",
    )
    observation = models.ForeignKey(
        "observations.Observation",
        on_delete=models.DO_NOTHING,
        null=True,
        related_name="nutrition_intake_part_of_reference_observation",
    )


class NutritionIntakeReportedReference(BaseReference):
    """Nutrition intake reported reference model."""

    identifier = models.ForeignKey(
        Identifier,
        on_delete=models.DO_NOTHING,
        null=True,
        related_name="nutrition_intake_reported_reference_identifier",
    )
    patient = models.ForeignKey(
        "patients.Patient",
        on_delete=models.DO_NOTHING,
        null=True,
        related_name="nutrition_intake_reported_reference_patient",
    )
    related_person = models.ForeignKey(
        "relatedpersons.RelatedPerson",
        on_delete=models.DO_NOTHING,
        null=True,
        related_name="nutrition_intake_reported_reference_related_person",
    )
    practitioner = models.ForeignKey(
        "practitioners.Practitioner",
        on_delete=models.DO_NOTHING,
        null=True,
        related_name="nutrition_intake_reported_reference_practitioner",
    )
    organization = models.ForeignKey(
        "organizations.Organization",
        on_delete=models.DO_NOTHING,
        null=True,
        related_name="nutrition_intake_reported_reference_organization",
    )
    group = models.ForeignKey(
        "groups.Group",
        on_delete=models.DO_NOTHING,
        null=True,
        related_name="nutrition_intake_reported_reference_group",
    )


class NutritionIntakeNutritionItemTotalIntake(TimeStampedModel):
    """nutrition intake nutrition item total intake model."""

    nutrient = models.ForeignKey(
        SubstanceCodeableReference,
        on_delete=models.DO_NOTHING,
        null=True,
        related_name="nutrition_intake_nutrition_item_total_intake_nutrient",
    )
    amount = models.ForeignKey(
        "base.Quantity",
        on_delete=models.DO_NOTHING,
        null=True,
        related_name="nutrition_intake_nutrition_item_total_intake_amount",
    )
    energy = models.ForeignKey(
        "base.Quantity",
        on_delete=models.DO_NOTHING,
        null=True,
        related_name="nutrition_intake_nutrition_item_total_intake_energy",
    )


class NutritionIntakeNutritionItemConsumedItem(TimeStampedModel):
    """nutrition intake nutrition item consumed item model."""

    schedule = models.ForeignKey(
        "base.Timing",
        on_delete=models.DO_NOTHING,
        null=True,
        related_name="nutrition_intake_nutrition_item_consumed_item_schedule",
    )
    amount = models.ForeignKey(
        "base.Quantity",
        on_delete=models.DO_NOTHING,
        null=True,
        related_name="nutrition_intake_nutrition_item_consumed_item_amount",
    )
    rate_quantity = models.ForeignKey(
        "base.Quantity",
        on_delete=models.DO_NOTHING,
        null=True,
        related_name="nutrition_intake_nutrition_item_consumed_item_rate_quantity",
    )
    rate_ratio = models.ForeignKey(
        "base.Ratio",
        on_delete=models.DO_NOTHING,
        null=True,
        related_name="nutrition_intake_nutrition_item_consumed_item_rate_ratio",
    )
    total_intake = models.ManyToManyField(
        NutritionIntakeNutritionItemTotalIntake,
        blank=True,
        related_name="nutrition_intake_nutrition_item_consumed_item_total_intake",
    )


class NutritionIntakeNutritionItem(TimeStampedModel):
    """nutrition intake nutrition item model."""

    type = models.ForeignKey(
        CodeableConcept,
        on_delete=models.DO_NOTHING,
        null=True,
        related_name="nutrition_intake_nutrition_item_type",
    )
    nutrition_product = models.ForeignKey(
        "nutritionproducts.NutritionProductCodeableReference",
        on_delete=models.DO_NOTHING,
        null=True,
        related_name="nutrition_intake_nutrition_item_nutrition_product",
    )
    consumed_item = models.ManyToManyField(
        NutritionIntakeNutritionItemConsumedItem,
        related_name="nutrition_intake_nutrition_item_consumed_item",
        blank=True,
    )
    not_consumed = models.BooleanField(default=False)
    not_consumed_reason = models.ForeignKey(
        CodeableConcept,
        on_delete=models.DO_NOTHING,
        null=True,
        related_name="nutrition_intake_nutrition_item_not_consumed_reason",
    )


class NutritionIntakePerformerActorReference(BaseReference):
    """nutrition intake performer actor reference model."""

    identifier = models.ForeignKey(
        Identifier,
        on_delete=models.DO_NOTHING,
        null=True,
        related_name="nutrition_intake_performer_actor_reference_identifier",
    )
    practitioner = models.ForeignKey(
        "practitioners.Practitioner",
        on_delete=models.DO_NOTHING,
        null=True,
        related_name="nutrition_intake_performer_actor_reference_practitioner",
    )
    practitioner_role = models.ForeignKey(
        "practitionerroles.PractitionerRole",
        on_delete=models.DO_NOTHING,
        null=True,
        related_name="nutrition_intake_performer_actor_reference_practitioner_role",
    )
    organization = models.ForeignKey(
        "organizations.Organization",
        on_delete=models.DO_NOTHING,
        null=True,
        related_name="nutrition_intake_performer_actor_reference_organization",
    )
    care_team = models.ForeignKey(
        "careteams.CareTeam",
        on_delete=models.DO_NOTHING,
        null=True,
        related_name="nutrition_intake_performer_actor_reference_care_team",
    )
    patient = models.ForeignKey(
        "patients.Patient",
        on_delete=models.DO_NOTHING,
        null=True,
        related_name="nutrition_intake_performer_actor_reference_patient",
    )
    device = models.ForeignKey(
        "devices.Device",
        on_delete=models.DO_NOTHING,
        null=True,
        related_name="nutrition_intake_performer_actor_reference_device",
    )
    related_person = models.ForeignKey(
        "relatedpersons.RelatedPerson",
        on_delete=models.DO_NOTHING,
        null=True,
        related_name="nutrition_intake_performer_actor_reference_related_person",
    )
    group = models.ForeignKey(
        "groups.Group",
        on_delete=models.DO_NOTHING,
        null=True,
        related_name="nutrition_intake_performer_actor_reference_group",
    )


class NutritionIntakePerformer(TimeStampedModel):
    """nutrition intake performer reference model."""

    function = models.ForeignKey(
        CodeableConcept,
        on_delete=models.DO_NOTHING,
        null=True,
        related_name="nutrition_intake_performer_reference_function",
    )
    actor = models.ForeignKey(
        NutritionIntakePerformerActorReference,
        on_delete=models.DO_NOTHING,
        null=True,
        related_name="nutrition_intake_performer_reference_actor",
    )


class NutritionIntakeReasonReference(BaseReference):
    """nutrition intake reason reference model."""

    identifier = models.ForeignKey(
        Identifier,
        on_delete=models.DO_NOTHING,
        null=True,
        related_name="nutrition_intake_reason_reference_identifier",
    )
    condition = models.ForeignKey(
        "conditions.Condition",
        on_delete=models.DO_NOTHING,
        null=True,
        related_name="nutrition_intake_reason_reference_condition",
    )
    observation = models.ForeignKey(
        "observations.Observation",
        on_delete=models.DO_NOTHING,
        null=True,
        related_name="nutrition_intake_reason_reference_observation",
    )
    diagnostic_report = models.ForeignKey(
        "diagnosticreports.DiagnosticReport",
        on_delete=models.DO_NOTHING,
        null=True,
        related_name="nutrition_intake_reason_reference_diagnostic_report",
    )
    document_reference = models.ForeignKey(
        "documentreferences.DocumentReference",
        on_delete=models.DO_NOTHING,
        null=True,
        related_name="nutrition_intake_reason_reference_document_reference",
    )


class NutritionIntakeReasonCodeableReference(TimeStampedModel):
    """nutrition intake codeable reference model."""

    concept = models.ForeignKey(
        CodeableConcept,
        on_delete=models.DO_NOTHING,
        null=True,
        related_name="nutrition_intake_reason_codeable_reference_concept",
    )
    reference = models.ForeignKey(
        NutritionIntakeReasonReference,
        on_delete=models.DO_NOTHING,
        null=True,
        related_name="nutrition_intake_codeable_reference_reference",
    )


class NutritionIntake(TimeStampedModel):
    """nutrition intake model."""

    identifier = models.ManyToManyField(
        Identifier, blank=True, related_name="nutrition_intake_identifier"
    )
    # TODO: instantiates_canonical = models.ManyToManyField(Definition)
    instantiates_uri = models.URLField(null=True)
    based_on = models.ManyToManyField(
        NutritionIntakeBasedOnReference,
        related_name="nutrition_intake_based_on",
        blank=True,
    )
    part_of = models.ManyToManyField(
        NutritionIntakePartOfReference,
        blank=True,
        related_name="nutrition_intake_part_of",
    )
    status = models.CharField(
        max_length=200, null=True, choices=NutritionIntakeStatusChoices.choices
    )
    status_reason = models.ManyToManyField(
        CodeableConcept,
        blank=True,
        related_name="nutrition_intake_status_reason",
    )
    code = models.ForeignKey(
        CodeableConcept,
        on_delete=models.DO_NOTHING,
        null=True,
        related_name="nutrition_intake_code",
    )
    subject = models.ForeignKey(
        "patients.PatientGroupReference",
        on_delete=models.DO_NOTHING,
        null=True,
        related_name="nutrition_intake_subject",
    )
    encounter = models.ForeignKey(
        "encounters.EncounterReference",
        on_delete=models.DO_NOTHING,
        null=True,
        related_name="nutrition_intake_encounter",
    )
    occurrence_date_time = models.DateTimeField(null=True)
    occurrence_period = models.ForeignKey(
        "base.Period",
        on_delete=models.DO_NOTHING,
        null=True,
        related_name="nutrition_intake_occurrence_period",
    )
    recorded = models.DateTimeField(null=True)
    reported_boolean = models.BooleanField(null=True)
    reported_reference = models.ForeignKey(
        NutritionIntakeReportedReference,
        on_delete=models.DO_NOTHING,
        null=True,
        related_name="nutrition_intake_reported_reference",
    )
    nutrition_item = models.ManyToManyField(
        NutritionIntakeNutritionItem,
        related_name="nutrition_intake_nutrition_item",
        blank=True,
    )
    performer = models.ManyToManyField(
        NutritionIntakePerformer,
        related_name="nutrition_intake_performer",
        blank=True,
    )
    location = models.ForeignKey(
        "locations.LocationReference",
        on_delete=models.DO_NOTHING,
        null=True,
        related_name="nutrition_intake_location",
    )
    derived_from = models.ManyToManyField(
        Reference, blank=True, related_name="nutrition_intake_derived_from"
    )
    reason = models.ManyToManyField(
        NutritionIntakeReasonCodeableReference,
        blank=True,
        related_name="nutrition_intake_reason_code",
    )
    note = models.ManyToManyField(
        "base.Annotation", blank=True, related_name="nutrition_intake_note"
    )


class NutritionIntakeReference(BaseReference):
    """nutrition intake reference model."""

    identifier = models.ForeignKey(
        Identifier,
        on_delete=models.DO_NOTHING,
        null=True,
        related_name="nutrition_intake_reference_identifier",
    )
    nutrition_intake = models.ForeignKey(
        "NutritionIntake",
        on_delete=models.DO_NOTHING,
        null=True,
        related_name="nutrition_intake_reference_nutrition_intake",
    )


class NutritionIntakeCodeableReference(TimeStampedModel):
    """nutrition intake codeable reference model."""

    concept = models.ForeignKey(
        CodeableConcept,
        on_delete=models.DO_NOTHING,
        null=True,
        related_name="nutrition_intake_codeable_reference_concept",
    )
    reference = models.ForeignKey(
        NutritionIntakeReference,
        on_delete=models.DO_NOTHING,
        null=True,
        related_name="nutrition_intake_codeable_reference_reference",
    )



# Generated by Django 5.2 on 2025-04-23 12:46

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('base', '0003_initial'),
        ('conditions', '0001_initial'),
    ]

    operations = [
        migrations.CreateModel(
            name='ConclusionCode',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('updated_at', models.DateTimeField(auto_now=True)),
                ('display', models.CharField(max_length=255)),
                ('code', models.CharField(max_length=255, null=True)),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='DiagnosticCategory',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('updated_at', models.DateTimeField(auto_now=True)),
                ('display', models.CharField(max_length=255)),
                ('description', models.TextField(blank=True)),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='DiagnosticReport',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('updated_at', models.DateTimeField(auto_now=True)),
                ('status', models.CharField(choices=[('registered', 'Registered'), ('partial', 'Partial'), ('preliminary', 'Preliminary'), ('modified', 'Modified'), ('final', 'Final'), ('amended', 'Amended'), ('corrected', 'Corrected'), ('appended', 'Appended'), ('cancelled', 'Cancelled'), ('entered_in_error', 'Entered in Error')], max_length=255, null=True)),
                ('effective_date_time', models.DateTimeField(null=True)),
                ('issued', models.DateTimeField(null=True)),
                ('conclusion', models.TextField(null=True)),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='DiagnosticReportBasedOnReference',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('updated_at', models.DateTimeField(auto_now=True)),
                ('reference', models.CharField(max_length=255, null=True)),
                ('type', models.CharField(max_length=255, null=True)),
                ('display', models.CharField(max_length=255, null=True)),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='DiagnosticReportCode',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('updated_at', models.DateTimeField(auto_now=True)),
                ('display', models.CharField(max_length=255)),
                ('code', models.CharField(max_length=255, null=True)),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='DiagnosticReportDocumentReferenceReference',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('updated_at', models.DateTimeField(auto_now=True)),
                ('reference', models.CharField(max_length=255, null=True)),
                ('type', models.CharField(max_length=255, null=True)),
                ('display', models.CharField(max_length=255, null=True)),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='DiagnosticReportEffective',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('updated_at', models.DateTimeField(auto_now=True)),
                ('effective_date_time', models.DateTimeField(null=True)),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='DiagnosticReportMedia',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('updated_at', models.DateTimeField(auto_now=True)),
                ('comment', models.TextField(blank=True)),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='DiagnosticReportPerformerReference',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('updated_at', models.DateTimeField(auto_now=True)),
                ('reference', models.CharField(max_length=255, null=True)),
                ('type', models.CharField(max_length=255, null=True)),
                ('display', models.CharField(max_length=255, null=True)),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='DiagnosticReportSubjectReference',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('updated_at', models.DateTimeField(auto_now=True)),
                ('reference', models.CharField(max_length=255, null=True)),
                ('type', models.CharField(max_length=255, null=True)),
                ('display', models.CharField(max_length=255, null=True)),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='SupportingInfo',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('updated_at', models.DateTimeField(auto_now=True)),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='SupportingInfoReference',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('updated_at', models.DateTimeField(auto_now=True)),
                ('reference', models.CharField(max_length=255, null=True)),
                ('type', models.CharField(max_length=255, null=True)),
                ('display', models.CharField(max_length=255, null=True)),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='ConclusionCodeCodeableReference',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('updated_at', models.DateTimeField(auto_now=True)),
                ('concept', models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='conclusion_code_codeable_reference_concept', to='base.codeableconcept')),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='ConclusionCodeReference',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('updated_at', models.DateTimeField(auto_now=True)),
                ('reference', models.CharField(max_length=255, null=True)),
                ('type', models.CharField(max_length=255, null=True)),
                ('display', models.CharField(max_length=255, null=True)),
                ('condition', models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='conclusion_code_condition', to='conditions.condition')),
                ('identifier', models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='conclusion_code_reference_identifier', to='base.identifier')),
            ],
            options={
                'abstract': False,
            },
        ),
    ]



# Generated by Django 5.2 on 2025-04-23 12:46

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('base', '0005_initial'),
        ('careteams', '0004_initial'),
        ('devicedefinitions', '0001_initial'),
        ('groups', '0003_initial'),
        ('nutritionorders', '0002_initial'),
        ('nutritionproducts', '0001_initial'),
        ('organizations', '0001_initial'),
        ('patients', '0002_initial'),
        ('practitionerroles', '0002_initial'),
        ('practitioners', '0001_initial'),
        ('relatedpersons', '0001_initial'),
        ('servicerequests', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='nutritionorderbasedonreference',
            name='service_request',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='nutrition_order_based_on_reference_service_request', to='servicerequests.servicerequest'),
        ),
        migrations.AddField(
            model_name='nutritionorder',
            name='based_on',
            field=models.ManyToManyField(blank=True, related_name='nutrition_order_based_on', to='nutritionorders.nutritionorderbasedonreference'),
        ),
        migrations.AddField(
            model_name='nutritionordercodeablereference',
            name='concept',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='nutrition_order_codeable_reference_concept', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='nutritionorderenteralformula',
            name='caloric_density',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='nutrition_order_enternal_formula_caloric_density', to='base.quantity'),
        ),
        migrations.AddField(
            model_name='nutritionorderenteralformula',
            name='delivery_Device',
            field=models.ManyToManyField(blank=True, related_name='nutrition_order_enternal_formula_delivery_device', to='devicedefinitions.devicedefinitioncodeablereference'),
        ),
        migrations.AddField(
            model_name='nutritionorderenteralformula',
            name='max_volume_to_administer',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='nutrition_order_enternal_formula_max_volume_to_administer', to='base.quantity'),
        ),
        migrations.AddField(
            model_name='nutritionorderenteralformula',
            name='route_of_administration',
            field=models.ManyToManyField(blank=True, related_name='nutrition_order_enternal_formula_route_of_administration', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='nutritionorderenteralformula',
            name='type',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='nutrition_order_enternal_formula_type', to='nutritionproducts.nutritionproductcodeablereference'),
        ),
        migrations.AddField(
            model_name='nutritionorder',
            name='enteral_formula',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='nutrition_order_enteral_formula', to='nutritionorders.nutritionorderenteralformula'),
        ),
        migrations.AddField(
            model_name='nutritionorderenteralformulaadministration',
            name='quantity',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='nutrition_order_enternal_formula_administration_quantity', to='base.quantity'),
        ),
        migrations.AddField(
            model_name='nutritionorderenteralformulaadministration',
            name='rate_quantity',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='nutrition_order_enternal_formula_administration_rate_quantity', to='base.quantity'),
        ),
        migrations.AddField(
            model_name='nutritionorderenteralformulaadministration',
            name='rate_ratio',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='nutrition_order_enternal_formula_administration_rate_ratio', to='base.ratio'),
        ),
        migrations.AddField(
            model_name='nutritionorderenteralformula',
            name='administration',
            field=models.ManyToManyField(blank=True, related_name='nutrition_order_enternal_formula_administration', to='nutritionorders.nutritionorderenteralformulaadministration'),
        ),
        migrations.AddField(
            model_name='nutritionorderoraldiet',
            name='caloric_density',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='nutrition_order_oral_diet_caloric_density', to='base.quantity'),
        ),
        migrations.AddField(
            model_name='nutritionorderoraldiet',
            name='type',
            field=models.ManyToManyField(related_name='nutrition_order_oral_diet_type', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='nutritionorder',
            name='oral_diet',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='nutrition_order_oral_diet', to='nutritionorders.nutritionorderoraldiet'),
        ),
        migrations.AddField(
            model_name='nutritionorderoraldietnutrient',
            name='amount',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='nutrition_order_oral_diet_nutrient_amount', to='base.quantity'),
        ),
        migrations.AddField(
            model_name='nutritionorderoraldietnutrient',
            name='modifier',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='nutrition_order_oral_diet_nutrient_modifier', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='nutritionorderoraldiet',
            name='nutrient',
            field=models.ManyToManyField(blank=True, related_name='nutrition_order_oral_diet_nutrient', to='nutritionorders.nutritionorderoraldietnutrient'),
        ),
        migrations.AddField(
            model_name='nutritionorderoraldiettexture',
            name='modifier',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='nutrition_order_oral_diet_texture_modifier', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='nutritionorderoraldiettexture',
            name='type',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='nutrition_order_oral_diet_texture_food_type', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='nutritionorderoraldiet',
            name='texture',
            field=models.ManyToManyField(blank=True, related_name='nutrition_order_oral_diet_texture', to='nutritionorders.nutritionorderoraldiettexture'),
        ),
        migrations.AddField(
            model_name='nutritionorderperformerreference',
            name='care_team',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='nutrition_order_performer_reference_care_team', to='careteams.careteam'),
        ),
        migrations.AddField(
            model_name='nutritionorderperformerreference',
            name='group',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='nutrition_order_performer_reference_group', to='groups.group'),
        ),
        migrations.AddField(
            model_name='nutritionorderperformerreference',
            name='identifier',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='nutrition_order_performer_reference_identifier', to='base.identifier'),
        ),
        migrations.AddField(
            model_name='nutritionorderperformerreference',
            name='organization',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='nutrition_order_performer_reference_organization', to='organizations.organization'),
        ),
        migrations.AddField(
            model_name='nutritionorderperformerreference',
            name='patient',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='nutrition_order_performer_reference_patient', to='patients.patient'),
        ),
        migrations.AddField(
            model_name='nutritionorderperformerreference',
            name='practitioner',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='nutrition_order_performer_reference_practitioner', to='practitioners.practitioner'),
        ),
        migrations.AddField(
            model_name='nutritionorderperformerreference',
            name='practitioner_role',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='nutrition_order_performer_reference_practitioner_role', to='practitionerroles.practitionerrole'),
        ),
        migrations.AddField(
            model_name='nutritionorderperformerreference',
            name='related_person',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='nutrition_order_performer_reference_related_person', to='relatedpersons.relatedperson'),
        ),
        migrations.AddField(
            model_name='nutritionorder',
            name='performer',
            field=models.ManyToManyField(blank=True, related_name='nutrition_order_performer', to='nutritionorders.nutritionorderperformerreference'),
        ),
        migrations.AddField(
            model_name='nutritionorderreference',
            name='identifier',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='nutrition_order_reference_identifier', to='base.identifier'),
        ),
        migrations.AddField(
            model_name='nutritionorderreference',
            name='nutrition_order',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='nutrition_order_reference_nutrition_order', to='nutritionorders.nutritionorder'),
        ),
        migrations.AddField(
            model_name='nutritionordercodeablereference',
            name='reference',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='nutrition_order_codeable_reference_reference', to='nutritionorders.nutritionorderreference'),
        ),
        migrations.AddField(
            model_name='nutritionorderschedule',
            name='as_needed_for',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='nutrition_order_oral_diet_schedule_as_needed_for', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='nutritionorderschedule',
            name='timing',
            field=models.ManyToManyField(blank=True, related_name='nutrition_order_oral_diet_schedule_timing', to='base.timing'),
        ),
        migrations.AddField(
            model_name='nutritionorderoraldiet',
            name='schedule',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='nutrition_order_oral_diet_schedule', to='nutritionorders.nutritionorderschedule'),
        ),
        migrations.AddField(
            model_name='nutritionorderenteralformulaadministration',
            name='schedule',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='nutrition_order_enternal_formula_administration_schedule', to='nutritionorders.nutritionorderschedule'),
        ),
        migrations.AddField(
            model_name='nutritionordersupplement',
            name='caloric_density',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='nutrition_order_supplement_caloric_density', to='base.quantity'),
        ),
        migrations.AddField(
            model_name='nutritionordersupplement',
            name='quantity',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='nutrition_order_supplement_quantity', to='base.quantity'),
        ),
        migrations.AddField(
            model_name='nutritionordersupplement',
            name='schedule',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='nutrition_order_supplement_schedule', to='nutritionorders.nutritionorderschedule'),
        ),
        migrations.AddField(
            model_name='nutritionordersupplement',
            name='type',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='nutrition_order_supplement_type', to='nutritionproducts.nutritionproductcodeablereference'),
        ),
        migrations.AddField(
            model_name='nutritionorder',
            name='supplement',
            field=models.ManyToManyField(blank=True, related_name='nutrition_order_supplement', to='nutritionorders.nutritionordersupplement'),
        ),
    ]



"""imaging study URL Configuration."""

from django.urls import path

from dfhir.imagingstudies import views

app_name = "imagingstudies"

urlpatterns = [
    path("imagingstudies/", views.ImagingStudyListView.as_view(), name="list"),
    path(
        "imagingstudies/<int:pk>/",
        views.ImagingStudyDetailView.as_view(),
        name="detail",
    ),
]



"""Detected issues urls."""

from django.urls import path

from . import views

app_name = "detectedissues"

urlpatterns = [
    path(
        "detectedissues/",
        views.DetectedIssueListView.as_view(),
        name="detectedissue-list-create",
    ),
    path(
        "detectedissues/<int:pk>/",
        views.DetectedIssueDetailView.as_view(),
        name="detectedissue-detail",
    ),
]



# Generated by Django 5.2 on 2025-04-23 12:46

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('base', '0005_initial'),
        ('careteams', '0004_initial'),
        ('goals', '0003_initial'),
        ('groups', '0002_initial'),
        ('organizations', '0001_initial'),
        ('patients', '0002_initial'),
        ('practitionerroles', '0002_initial'),
        ('practitioners', '0001_initial'),
        ('procedures', '0001_initial'),
        ('relatedpersons', '0001_initial'),
        ('riskassessments', '0001_initial'),
        ('servicerequests', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='goaladdressesreference',
            name='procedure',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='goal_addresses_reference_procedure', to='procedures.procedure'),
        ),
        migrations.AddField(
            model_name='goaladdressesreference',
            name='risk_assessment',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='goal_addresses_reference_risk_assessment', to='riskassessments.riskassessment'),
        ),
        migrations.AddField(
            model_name='goaladdressesreference',
            name='service_request',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='goal_addresses_reference_service_request', to='servicerequests.servicerequest'),
        ),
        migrations.AddField(
            model_name='goal',
            name='addresses',
            field=models.ManyToManyField(blank=True, related_name='goal_addresses', to='goals.goaladdressesreference'),
        ),
        migrations.AddField(
            model_name='goalsourcereference',
            name='care_team',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='goal_source_reference_care_team', to='careteams.careteam'),
        ),
        migrations.AddField(
            model_name='goalsourcereference',
            name='identifier',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='goal_source_reference_identifier', to='base.identifier'),
        ),
        migrations.AddField(
            model_name='goalsourcereference',
            name='patient',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='goal_source_reference_patient', to='patients.patient'),
        ),
        migrations.AddField(
            model_name='goalsourcereference',
            name='practitioner',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='goal_source_reference_practitioner', to='practitioners.practitioner'),
        ),
        migrations.AddField(
            model_name='goalsourcereference',
            name='practitioner_role',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='goal_source_reference_practitioner_role', to='practitionerroles.practitionerrole'),
        ),
        migrations.AddField(
            model_name='goalsourcereference',
            name='related_person',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='goal_source_reference_related_person', to='relatedpersons.relatedperson'),
        ),
        migrations.AddField(
            model_name='goal',
            name='source',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='goal_source', to='goals.goalsourcereference'),
        ),
        migrations.AddField(
            model_name='goalsubjectreference',
            name='group',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='goal_subject_reference_group', to='groups.group'),
        ),
        migrations.AddField(
            model_name='goalsubjectreference',
            name='identifier',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='goal_subject_reference_identifier', to='base.identifier'),
        ),
        migrations.AddField(
            model_name='goalsubjectreference',
            name='organization',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='goal_subject_reference_organization', to='organizations.organization'),
        ),
        migrations.AddField(
            model_name='goalsubjectreference',
            name='patient',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='goal_subject_reference_patient', to='patients.patient'),
        ),
        migrations.AddField(
            model_name='goal',
            name='subject',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='goal_subject', to='goals.goalsubjectreference'),
        ),
        migrations.AddField(
            model_name='goaltarget',
            name='detail_codeable_concept',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='goal_target_detail_codeable_concept', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='goaltarget',
            name='detail_quantity',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='goal_target_detail_quantity', to='base.quantity'),
        ),
        migrations.AddField(
            model_name='goaltarget',
            name='detail_range',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='goal_target_detail_range', to='base.range'),
        ),
        migrations.AddField(
            model_name='goaltarget',
            name='detail_ratio',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='goal_target_detail_ratio', to='base.ratio'),
        ),
        migrations.AddField(
            model_name='goaltarget',
            name='due_duration',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='goal_target_due_duration', to='base.duration'),
        ),
        migrations.AddField(
            model_name='goaltarget',
            name='measure',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='goal_target_measure', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='goal',
            name='target',
            field=models.ManyToManyField(blank=True, related_name='goal_target', to='goals.goaltarget'),
        ),
    ]



"""organization affiliation urls."""

from django.urls import path

from dfhir.organizationaffiliations.views import (
    OrganizationAffiliationDetailview,
    OrganizationAffiliationListview,
)

app_name = "organizationaffiliations"

urlpatterns = [
    path(
        "organizationaffiliations/",
        OrganizationAffiliationListview.as_view(),
        name="organizationaffiliations-list",
    ),
    path(
        "organizationaffiliations/<int:pk>/",
        OrganizationAffiliationDetailview.as_view(),
        name="organizationaffiliations-detail",
    ),
]



"""Account Serializers."""

from drf_writable_nested.serializers import WritableNestedModelSerializer

from dfhir.base.serializers import (
    BaseReferenceModelSerializer,
    BaseWritableNestedModelSerializer,
    CodeableConceptSerializer,
    IdentifierSerializer,
    MoneySerializer,
    OrganizationReferenceSerializer,
    PeriodSerializer,
)
from dfhir.conditions.serializers import ConditionCodeableReferenceSerializer
from dfhir.coverages.serializers import CoverageReferenceSerializer
from dfhir.devices.serializers import DeviceReferenceSerializer
from dfhir.encounters.serializers import EncounterEpisodeOfCareReferenceSerializer
from dfhir.procedures.serializers import ProcedureCodeableReferenceSerializer

from .models import (
    Account,
    AccountBalance,
    AccountCoverage,
    AccountDiagnosis,
    AccountGuarantor,
    AccountProcedure,
    AccountReference,
    AccountRelatedAccount,
    AccountsGuarantorPartyReference,
    AccountSubjectReference,
)


class AccountReferenceSerializer(BaseReferenceModelSerializer):
    """Account reference serializer."""

    identifier = IdentifierSerializer(required=False)

    class Meta:
        """Meta class."""

        model = AccountReference
        exclude = ["created_at", "updated_at"]


class AccountDiagnosisSerializer(WritableNestedModelSerializer):
    """Account diagnosis serializer."""

    condition = ConditionCodeableReferenceSerializer(required=False)
    type = CodeableConceptSerializer(many=True, required=False)
    package_code = CodeableConceptSerializer(many=True, required=False)

    class Meta:
        """Meta class."""

        model = AccountDiagnosis
        exclude = ["created_at", "updated_at"]


class AccountGuarantorPartyReferenceSerializer(BaseReferenceModelSerializer):
    """Account guarantor party reference serializer."""

    identifier = IdentifierSerializer(required=False)

    class Meta:
        """Meta class."""

        model = AccountsGuarantorPartyReference
        exclude = ["created_at", "updated_at"]


class AccountGuarantorSerializer(WritableNestedModelSerializer):
    """Account guarantor serializer."""

    party = AccountGuarantorPartyReferenceSerializer(required=False)
    period = PeriodSerializer(required=False)

    class Meta:
        """Meta class."""

        model = AccountGuarantor
        exclude = ["created_at", "updated_at"]


class AccountBalanceSerializer(WritableNestedModelSerializer):
    """Account balance serializer."""

    aggregate = CodeableConceptSerializer(required=False)
    term = CodeableConceptSerializer(required=False)
    amount = MoneySerializer(required=False)

    class Meta:
        """Meta class."""

        model = AccountBalance
        exclude = ["created_at", "updated_at"]


class AccountCoverageSerializer(WritableNestedModelSerializer):
    """Account coverage serializer."""

    coverage = CoverageReferenceSerializer(required=False)

    class Meta:
        """Meta class."""

        model = AccountCoverage
        exclude = ["created_at", "updated_at"]


class AccountProcedureSerializer(WritableNestedModelSerializer):
    """Account procedure serializer."""

    code = ProcedureCodeableReferenceSerializer(required=False)
    type = CodeableConceptSerializer(many=True, required=False)
    package_code = CodeableConceptSerializer(many=True, required=False)
    device = DeviceReferenceSerializer(many=True, required=False)

    class Meta:
        """Meta class."""

        model = AccountProcedure
        exclude = ["created_at", "updated_at"]


class AccountRelatedAccountSerializer(WritableNestedModelSerializer):
    """Account related account serializer."""

    relationship = CodeableConceptSerializer(required=False)
    account = AccountReferenceSerializer(required=False)

    class Meta:
        """Meta class."""

        model = AccountRelatedAccount
        exclude = ["created_at", "updated_at"]


class AccountSubjectReferenceSerializer(WritableNestedModelSerializer):
    """Account subject reference serializer."""

    identifier = IdentifierSerializer(required=False)

    class Meta:
        """Meta class."""

        model = AccountSubjectReference
        exclude = ["created_at", "updated_at"]


class AccountSerializer(BaseWritableNestedModelSerializer):
    """Account serializer."""

    identifier = IdentifierSerializer(many=True, required=False)
    billing_status = CodeableConceptSerializer(required=False)
    type = CodeableConceptSerializer(required=False)
    subject = AccountSubjectReferenceSerializer(many=True, required=False)
    service_period = PeriodSerializer(required=False)
    covers = EncounterEpisodeOfCareReferenceSerializer(many=True, required=False)
    coverage = AccountCoverageSerializer(many=True, required=False)
    owner = OrganizationReferenceSerializer(required=False)
    guarantor = AccountGuarantorSerializer(many=True, required=False)
    diagnosis = AccountDiagnosisSerializer(many=True, required=False)
    procedure = AccountProcedureSerializer(many=True, required=False)
    related_account = AccountRelatedAccountSerializer(many=True, required=False)
    currency = CodeableConceptSerializer(required=False)
    balance = AccountBalanceSerializer(many=True, required=False)

    class Meta:
        """Meta class."""

        model = Account
        exclude = ["created_at", "updated_at"]



"""body structure module."""

from django.db import models

from dfhir.base.models import (
    Attachment,
    BaseReference,
    CodeableConcept,
    Identifier,
    Quantity,
    TimeStampedModel,
)
from dfhir.imagingselections.models import ImagingSelectionReference


class DistanceFromLandmark(TimeStampedModel):
    """distance from landmark model."""

    device = models.ManyToManyField(
        "devices.DeviceCodeableReference",
        blank=True,
        related_name="distance_from_landmark_device",
    )
    value = models.ManyToManyField(
        Quantity, blank=True, related_name="distance_from_landmark_value"
    )


class BodyLandmarkOrientation(TimeStampedModel):
    """body landmark orientation model."""

    landmark_description = models.ManyToManyField(
        CodeableConcept,
        blank=True,
        related_name="body_landmark_orientation_landmark_description",
    )
    clock_face_position = models.ManyToManyField(
        CodeableConcept,
        blank=True,
        related_name="body_landmark_orientation_clock_face_position",
    )
    distance_from_landmark = models.ManyToManyField(
        DistanceFromLandmark,
        blank=True,
        related_name="body_landmark_orientation_distance_from_landmark",
    )
    surface_orientation = models.ManyToManyField(
        CodeableConcept,
        blank=True,
        related_name="body_landmark_orientation_surface_orientation",
    )


class IncludedStructure(TimeStampedModel):
    """included structure model."""

    structure = models.ForeignKey(
        CodeableConcept,
        on_delete=models.DO_NOTHING,
        null=True,
        related_name="included_structure_structure",
    )
    laterality = models.ForeignKey(
        CodeableConcept,
        on_delete=models.DO_NOTHING,
        null=True,
        related_name="included_structure_laterality",
    )
    body_landmark_orientation = models.ManyToManyField(
        BodyLandmarkOrientation,
        blank=True,
        related_name="included_structure_body_landmark_orientation",
    )
    spatial_reference = models.ManyToManyField(
        ImagingSelectionReference,
        blank=True,
        related_name="included_structure_spatial_reference",
    )
    qualifier = models.ManyToManyField(
        CodeableConcept, blank=True, related_name="included_structure_qualifier"
    )


# Create your models here.
class BodyStructure(TimeStampedModel):
    """body structure model."""

    identifier = models.ManyToManyField(
        Identifier,
        blank=True,
        related_query_name="body_structure_identifier",
    )
    active = models.BooleanField(default=True)
    morphology = models.ForeignKey(
        CodeableConcept,
        on_delete=models.CASCADE,
        null=True,
        related_name="body_structure_morphology",
    )
    included_structure = models.ManyToManyField(
        IncludedStructure, related_name="body_structure_included_structure", blank=True
    )
    excluded_structure = models.ManyToManyField(
        IncludedStructure, blank=True, related_name="body_structure_excluded_structure"
    )
    description = models.TextField(null=True)
    image = models.ManyToManyField(
        Attachment, blank=True, related_name="body_structure_image"
    )
    patient = models.ForeignKey(
        "patients.PatientReference",
        on_delete=models.DO_NOTHING,
        null=True,
        related_name="body_structure_patient",
    )


class BodyStructureReference(BaseReference):
    """body structure reference model."""

    identifier = models.ForeignKey(Identifier, on_delete=models.SET_NULL, null=True)
    body_structure = models.ForeignKey(
        BodyStructure, on_delete=models.SET_NULL, null=True
    )


class BodyStructureCodeableReference(TimeStampedModel):
    """body structure codeable reference model."""

    reference = models.ForeignKey(
        BodyStructureReference, on_delete=models.SET_NULL, null=True
    )
    concept = models.ForeignKey(CodeableConcept, on_delete=models.SET_NULL, null=True)



"""Charge items app configuration."""

from django.apps import AppConfig
from django.utils.translation import gettext_lazy as _


class ChargeitemsConfig(AppConfig):
    """Charge items app config."""

    default_auto_field = "django.db.models.BigAutoField"
    name = "dfhir.chargeitems"
    verbose_name = _("Charge Items")



"""formulary item serializers."""

from dfhir.base.serializers import (
    BaseWritableNestedModelSerializer,
    CodeableConceptSerializer,
    IdentifierSerializer,
)
from dfhir.formularyitems.models import FormularyItem, FormularyItemReference


class FormularyItemSerializer(BaseWritableNestedModelSerializer):
    """formulary item serializer."""

    identifier = IdentifierSerializer(many=True, required=False)
    code = CodeableConceptSerializer(required=False)

    class Meta:
        """Meta options."""

        model = FormularyItem
        exclude = ["created_at", "updated_at"]


class FormularyItemReferenceSerializer(BaseWritableNestedModelSerializer):
    """formulary item reference serializer."""

    identifier = IdentifierSerializer(required=False)

    class Meta:
        """Meta options."""

        model = FormularyItemReference
        exclude = ["created_at", "updated_at"]



# Generated by Django 5.2 on 2025-04-23 12:46

import django.contrib.postgres.fields
import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('base', '0001_initial'),
    ]

    operations = [
        migrations.CreateModel(
            name='EndpointPayload',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('updated_at', models.DateTimeField(auto_now=True)),
                ('mime_type', django.contrib.postgres.fields.ArrayField(base_field=models.CharField(max_length=255), null=True, size=None)),
                ('profile_uri', models.CharField(max_length=255, null=True)),
                ('type', models.ManyToManyField(blank=True, related_name='endpoint_payload_type', to='base.codeableconcept')),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='Endpoint',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('updated_at', models.DateTimeField(auto_now=True)),
                ('status', models.CharField(choices=[('active', 'active'), ('limited', 'limited'), ('suspended', 'suspended'), ('error', 'error'), ('off', 'off'), ('entered-in-error', 'entered-in-error')], max_length=255, null=True)),
                ('name', models.CharField(max_length=255, null=True)),
                ('description', models.TextField(null=True)),
                ('address', models.CharField(max_length=255, null=True)),
                ('header', django.contrib.postgres.fields.ArrayField(base_field=models.CharField(max_length=255), null=True, size=None)),
                ('availability', models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='endpoint_availability', to='base.availability')),
                ('connection_type', models.ManyToManyField(blank=True, related_name='endpoint_connection_type', to='base.codeableconcept')),
                ('contact', models.ManyToManyField(blank=True, related_name='endpoint_contact', to='base.contactpoint')),
                ('environmental_type', models.ManyToManyField(blank=True, related_name='endpoint_environmental_type', to='base.codeableconcept')),
                ('identifier', models.ManyToManyField(blank=True, related_name='endpoint_identifier', to='base.identifier')),
                ('managing_organization', models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='endpoint_managing_organization', to='base.organizationreference')),
                ('period', models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='endpoint_period', to='base.period')),
                ('payload', models.ManyToManyField(blank=True, related_name='endpoint_payload', to='endpoints.endpointpayload')),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='EndpointReference',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('updated_at', models.DateTimeField(auto_now=True)),
                ('reference', models.CharField(max_length=255, null=True)),
                ('type', models.CharField(max_length=255, null=True)),
                ('display', models.CharField(max_length=255, null=True)),
                ('endpoint', models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='endpoint_reference', to='endpoints.endpoint')),
                ('identifier', models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='endpoint_reference_identifier', to='base.identifier')),
            ],
            options={
                'abstract': False,
            },
        ),
    ]



"""Claim responses urls."""

from django.urls import path

from . import views

app_name = "claimresponses"


urlpatterns = [
    path("claimresponses/", views.ClaimResponseListView.as_view()),
    path("claimresponses/<int:pk>/", views.ClaimResponseDetailView.as_view()),
]



"""EnrollmentResponses views."""

from django.http import Http404
from drf_spectacular.utils import extend_schema
from rest_framework import status
from rest_framework.permissions import AllowAny
from rest_framework.response import Response
from rest_framework.views import APIView

from .models import EnrollmentResponse
from .serializers import EnrollmentResponseSerializer


class EnrollmentResponseListView(APIView):
    """EnrollmentResponse list view."""

    permission_classes = [AllowAny]

    @extend_schema(responses={200: EnrollmentResponseSerializer(many=True)})
    def get(self, request):
        """Get a list of enrollment responses."""
        enrollment_responses = EnrollmentResponse.objects.all()
        serializer = EnrollmentResponseSerializer(enrollment_responses, many=True)
        return Response(serializer.data, status=status.HTTP_200_OK)

    @extend_schema(
        request=EnrollmentResponseSerializer,
        responses={201: EnrollmentResponseSerializer},
    )
    def post(self, request):
        """Create an enrollment response."""
        serializer = EnrollmentResponseSerializer(data=request.data)
        serializer.is_valid(raise_exception=True)
        serializer.save()
        return Response(serializer.data, status=status.HTTP_201_CREATED)


class EnrollmentResponseDetailView(APIView):
    """EnrollmentResponse detail view."""

    permission_classes = [AllowAny]

    def get_object(self, pk):
        """Get an enrollment response object."""
        try:
            return EnrollmentResponse.objects.get(pk=pk)
        except EnrollmentResponse.DoesNotExist as err:
            raise Http404 from err

    @extend_schema(responses={200: EnrollmentResponseSerializer})
    def get(self, request, pk=None):
        """Get an enrollment response."""
        enrollment_response = self.get_object(pk)
        serializer = EnrollmentResponseSerializer(enrollment_response)
        return Response(serializer.data, status=status.HTTP_200_OK)

    @extend_schema(
        request=EnrollmentResponseSerializer,
        responses={200: EnrollmentResponseSerializer},
    )
    def patch(self, request, pk=None):
        """Update an enrollment response."""
        enrollment_response = self.get_object(pk)
        serializer = EnrollmentResponseSerializer(
            enrollment_response, data=request.data, partial=True
        )
        serializer.is_valid(raise_exception=True)
        serializer.save()
        return Response(serializer.data, status=status.HTTP_200_OK)

    @extend_schema(responses={204: None})
    def delete(self, request, pk=None):
        """Delete an enrollment response."""
        enrollment_response = self.get_object(pk)
        enrollment_response.delete()
        return Response(status=status.HTTP_204_NO_CONTENT)



"""Coverage views."""

from django.http import Http404
from drf_spectacular.utils import extend_schema
from rest_framework import status
from rest_framework.permissions import AllowAny
from rest_framework.response import Response
from rest_framework.views import APIView

from .models import Coverage
from .serializers import CoverageSerializer


class CoverageListView(APIView):
    """Coverage list view."""

    permission_classes = [AllowAny]

    @extend_schema(responses={200: CoverageSerializer(many=True)})
    def get(self, request):
        """Get a list of coverages."""
        coverages = Coverage.objects.all()
        serializer = CoverageSerializer(coverages, many=True)
        return Response(serializer.data, status=status.HTTP_200_OK)

    @extend_schema(request=CoverageSerializer, responses={201: CoverageSerializer})
    def post(self, request):
        """Create a coverage."""
        serializer = CoverageSerializer(data=request.data)
        serializer.is_valid(raise_exception=True)
        serializer.save()

        return Response(serializer.data, status=status.HTTP_201_CREATED)


class CoverageDetailView(APIView):
    """Coverage detail view."""

    permission_classes = [AllowAny]

    def get_object(self, pk):
        """Get a coverage object."""
        try:
            return Coverage.objects.get(pk=pk)
        except Coverage.DoesNotExist as err:
            raise Http404 from err

    @extend_schema(responses={200: CoverageSerializer})
    def get(self, request, pk):
        """Get a coverage."""
        coverage = self.get_object(pk)
        serializer = CoverageSerializer(coverage)
        return Response(serializer.data, status=status.HTTP_200_OK)

    @extend_schema(request=CoverageSerializer, responses={200: CoverageSerializer})
    def patch(self, request, pk):
        """Update a coverage."""
        coverage = self.get_object(pk)
        serializer = CoverageSerializer(coverage, data=request.data, partial=True)
        serializer.is_valid(raise_exception=True)
        serializer.save()
        return Response(serializer.data, status=status.HTTP_200_OK)

    @extend_schema(responses={204: None})
    def delete(self, request, pk):
        """Delete a coverage."""
        coverage = self.get_object(pk)
        coverage.delete()
        return Response(status=status.HTTP_204_NO_CONTENT)



# Generated by Django 5.2 on 2025-04-23 12:46

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('base', '0004_initial'),
        ('chargeitems', '0002_initial'),
        ('conditions', '0002_initial'),
        ('diagnosticreports', '0002_initial'),
        ('immunizationrecommendations', '0002_initial'),
        ('observations', '0001_initial'),
        ('patients', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='chargeitem',
            name='subject',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='charge_item_subject', to='patients.patientgroupreference'),
        ),
        migrations.AddField(
            model_name='chargeitem',
            name='supporting_information',
            field=models.ManyToManyField(blank=True, related_name='charge_item_supporting_information', to='base.reference'),
        ),
        migrations.AddField(
            model_name='chargeitem',
            name='total_price_component',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='charge_item_total_price_component', to='base.monetarycomponent'),
        ),
        migrations.AddField(
            model_name='chargeitem',
            name='unit_price_component',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='charge_item_unit_price_component', to='base.monetarycomponent'),
        ),
        migrations.AddField(
            model_name='chargeitementererreference',
            name='condition',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='charge_item_enterer_reference_condition', to='conditions.condition'),
        ),
        migrations.AddField(
            model_name='chargeitementererreference',
            name='diagnostic_report',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='charge_item_enterer_reference_diagnostic_report', to='diagnosticreports.diagnosticreport'),
        ),
        migrations.AddField(
            model_name='chargeitementererreference',
            name='identifier',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='charge_item_enterer_reference_identifier', to='base.identifier'),
        ),
        migrations.AddField(
            model_name='chargeitementererreference',
            name='immunization_recommendation',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='charge_item_enterer_reference_immunization_recommendation', to='immunizationrecommendations.immunizationrecommendation'),
        ),
        migrations.AddField(
            model_name='chargeitementererreference',
            name='observation',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='charge_item_enterer_reference_observation', to='observations.observation'),
        ),
    ]



"""imaging selection url config."""

from django.urls import path

from dfhir.imagingselections import views

app_name = "imagingselections"

urlpatterns = [
    path("imagingselections/", views.ImagingSelectionListView.as_view()),
    path("imagingselections/<int:pk>/", views.ImagingSelectionDetailView.as_view()),
]



"""Device definitions serializer."""

from drf_writable_nested.serializers import WritableNestedModelSerializer

from dfhir.base.serializers import (
    AttachmentSerializer,
    BaseWritableNestedModelSerializer,
    CodeableConceptSerializer,
    CodingSerializer,
    ContactDetailSerializer,
    IdentifierSerializer,
    OrganizationReferenceSerializer,
    PeriodSerializer,
    ProductShelfLifeSerializer,
    QuantitySerializer,
    RangeSerializer,
    RatioSerializer,
    RelatedArtifactSerializer,
    UsageContextSerializer,
)

from .models import (
    DeviceDefinition,
    DeviceDefinitionChargeItem,
    DeviceDefinitionClassification,
    DeviceDefinitionCodeableReference,
    DeviceDefinitionConformsTo,
    DeviceDefinitionCorrectiveAction,
    DeviceDefinitionDeviceName,
    DeviceDefinitionDeviceVersion,
    DeviceDefinitionGuideline,
    DeviceDefinitionHasPart,
    DeviceDefinitionLink,
    DeviceDefinitionMarketDistribution,
    DeviceDefinitionMaterial,
    DeviceDefinitionPackaging,
    DeviceDefinitionPackagingDistributor,
    DeviceDefinitionProperty,
    DeviceDefinitionReference,
    DeviceDefinitionRegulatoryIdentifier,
    DeviceDefinitionUdiDeviceIdentifier,
)


class DeviceDefinitionRegulatoryIdentifierSerializer(WritableNestedModelSerializer):
    """Device Definition Regulatory Identifier serializer."""

    class Meta:
        """Meta class."""

        model = DeviceDefinitionRegulatoryIdentifier
        exclude = ["created_at", "updated_at"]


class DeviceDefinitionPropertySerializer(WritableNestedModelSerializer):
    """Device Definition Property serializer."""

    type = CodeableConceptSerializer(many=False, required=False)
    value_quantity = QuantitySerializer(many=False, required=False)
    value_codeable_concept = CodeableConceptSerializer(many=False, required=False)
    value_range = RangeSerializer(many=False, required=False)
    value_ratio = RatioSerializer(many=False, required=False)
    value_attachment = AttachmentSerializer(many=False, required=False)

    class Meta:
        """Meta class."""

        model = DeviceDefinitionProperty
        exclude = ["created_at", "updated_at"]


class DeviceDefinitionMarketDistributionSerializer(WritableNestedModelSerializer):
    """Device Definition Market Distribution serializer."""

    market_period = PeriodSerializer(many=False, required=False)

    class Meta:
        """Meta class."""

        model = DeviceDefinitionMarketDistribution
        exclude = ["created_at", "updated_at"]


class DeviceDefinitionUdiDeviceIdentifierSerializer(WritableNestedModelSerializer):
    """Device Definition UDI Device Identifier serializer."""

    market_distribution = DeviceDefinitionMarketDistributionSerializer(
        many=True, required=False
    )

    class Meta:
        """Meta class."""

        model = DeviceDefinitionUdiDeviceIdentifier
        exclude = ["created_at", "updated_at"]


class DeviceDefinitionDeviceVersionSerializer(WritableNestedModelSerializer):
    """Device Version serializer."""

    type = CodeableConceptSerializer(many=False, required=False)
    component = IdentifierSerializer(many=False, required=False)

    class Meta:
        """Meta class."""

        model = DeviceDefinitionDeviceVersion
        exclude = ["created_at", "updated_at"]


class DeviceDefinitionReferenceSerializer(WritableNestedModelSerializer):
    """Device Definition Reference serializer."""

    identifier = IdentifierSerializer(many=False, required=False)

    class Meta:
        """Meta class."""

        model = DeviceDefinitionReference
        exclude = ["created_at", "updated_at"]


class DeviceDefinitionCodeableReferenceSerializer(WritableNestedModelSerializer):
    """Device Definition Codeable Reference serializer."""

    reference = DeviceDefinitionReferenceSerializer(many=False, required=False)
    concept = CodeableConceptSerializer(many=False, required=False)

    class Meta:
        """Meta class."""

        model = DeviceDefinitionCodeableReference
        exclude = ["created_at", "updated_at"]


class DeviceDefinitionLinkSerializer(WritableNestedModelSerializer):
    """Device Definition Link serializer."""

    relation = CodingSerializer(many=False, required=False)
    related_device = DeviceDefinitionCodeableReferenceSerializer(
        many=False, required=False
    )

    class Meta:
        """Meta class."""

        model = DeviceDefinitionLink
        exclude = ["created_at", "updated_at"]


class DeviceDefinitionMaterialSerializer(WritableNestedModelSerializer):
    """Device Definition Material serializer."""

    substance = CodeableConceptSerializer(many=False, required=False)

    class Meta:
        """Meta class."""

        model = DeviceDefinitionMaterial
        exclude = ["created_at", "updated_at"]


class DeviceDefinitionClassificationSerializer(WritableNestedModelSerializer):
    """Device Definition Classification serializer."""

    type = CodeableConceptSerializer(many=False, required=False)
    justification = RelatedArtifactSerializer(many=True, required=False)

    class Meta:
        """Meta class."""

        model = DeviceDefinitionClassification
        exclude = ["created_at", "updated_at"]


class DeviceDefinitionGuidelineSerializer(WritableNestedModelSerializer):
    """Device Definition Guideline serializer."""

    use_context = UsageContextSerializer(many=True, required=False)
    related_artifact = RelatedArtifactSerializer(many=True, required=False)
    indication = CodeableConceptSerializer(many=True, required=False)
    contraindication = CodeableConceptSerializer(many=True, required=False)
    warning = CodeableConceptSerializer(many=True, required=False)

    class Meta:
        """Meta class."""

        model = DeviceDefinitionGuideline
        exclude = ["created_at", "updated_at"]


class DeviceDefinitionPackagingDistributorSerializer(WritableNestedModelSerializer):
    """Device Definition Packaging Distributor serializer."""

    organization_reference = OrganizationReferenceSerializer(many=False, required=False)

    class Meta:
        """Meta class."""

        model = DeviceDefinitionPackagingDistributor
        exclude = ["created_at", "updated_at"]


class DeviceDefinitionPackagingSerializer(WritableNestedModelSerializer):
    """Device Definition Packaging serializer."""

    identifier = IdentifierSerializer(many=False, required=False)
    type = CodeableConceptSerializer(many=False, required=False)
    distributor = DeviceDefinitionPackagingDistributorSerializer(
        many=True, required=False
    )
    udi_device_identifier = DeviceDefinitionUdiDeviceIdentifierSerializer(
        many=True, required=False
    )

    class Meta:
        """Meta class."""

        model = DeviceDefinitionPackaging
        exclude = ["created_at", "updated_at"]


class DeviceDefinitionHasPartSerializer(WritableNestedModelSerializer):
    """Device Definition Has Part serializer."""

    reference = DeviceDefinitionReferenceSerializer(many=False, required=False)

    class Meta:
        """Meta class."""

        model = DeviceDefinitionHasPart
        exclude = ["created_at", "updated_at"]


class DeviceDefinitionDeviceNameSerializer(WritableNestedModelSerializer):
    """Device Definition Device Name serializer."""

    type = CodeableConceptSerializer(many=False, required=False)

    class Meta:
        """Meta class."""

        model = DeviceDefinitionDeviceName
        exclude = ["created_at", "updated_at"]


class DeviceDefinitionChargeItemSerializer(WritableNestedModelSerializer):
    """Device Definition Charge Item serializer."""

    count = QuantitySerializer(many=False, required=False)
    effective_period = PeriodSerializer(many=False, required=False)
    use_context = UsageContextSerializer(many=True, required=False)

    class Meta:
        """Meta class."""

        model = DeviceDefinitionChargeItem
        exclude = ["created_at", "updated_at"]


class DeviceDefinitionConformsToSerializer(WritableNestedModelSerializer):
    """Device Definition Conforms To serializer."""

    category = CodeableConceptSerializer(many=False, required=False)
    specification = CodeableConceptSerializer(many=False, required=False)
    source = RelatedArtifactSerializer(many=True, required=False)

    class Meta:
        """Meta class."""

        model = DeviceDefinitionConformsTo
        exclude = ["created_at", "updated_at"]


class DeviceDefinitionCorrectiveActionSerializer(WritableNestedModelSerializer):
    """Device Definition Corrective Action serializer."""

    period = PeriodSerializer(many=False, required=False)

    class Meta:
        """Meta class."""

        model = DeviceDefinitionCorrectiveAction
        exclude = ["created_at", "updated_at"]


class DeviceDefinitionSerializer(BaseWritableNestedModelSerializer):
    """Device Definition serializer."""

    identifier = IdentifierSerializer(many=True, required=False)
    udiDeviceIdentifier = DeviceDefinitionUdiDeviceIdentifierSerializer(
        many=True, required=False
    )
    regulatory_identifier = DeviceDefinitionRegulatoryIdentifierSerializer(
        many=True, required=False
    )
    manufacturer = OrganizationReferenceSerializer(many=False, required=False)
    device_name = DeviceDefinitionDeviceNameSerializer(many=True, required=False)
    contact = ContactDetailSerializer(many=True, required=False)
    classification = DeviceDefinitionClassificationSerializer(many=True, required=False)
    conforms_to = DeviceDefinitionConformsToSerializer(many=True, required=False)
    has_part = DeviceDefinitionHasPartSerializer(many=True, required=False)
    packaging = DeviceDefinitionPackagingSerializer(many=True, required=False)
    device_version = DeviceDefinitionDeviceVersionSerializer(many=True, required=False)
    safety = CodeableConceptSerializer(many=True, required=False)
    shelf_life_storage = ProductShelfLifeSerializer(many=False, required=False)
    language_code = CodeableConceptSerializer(many=False, required=False)
    property = DeviceDefinitionPropertySerializer(many=True, required=False)
    link = DeviceDefinitionLinkSerializer(many=True, required=False)
    material = DeviceDefinitionMaterialSerializer(many=True, required=False)
    guideline = DeviceDefinitionGuidelineSerializer(many=False, required=False)
    corrective_action = DeviceDefinitionCorrectiveActionSerializer(
        many=False, required=False
    )
    charge_item = DeviceDefinitionChargeItemSerializer(many=True, required=False)

    class Meta:
        """Meta class."""

        model = DeviceDefinition
        exclude = ["created_at", "updated_at"]



"""Devicedispenses urls."""

from django.urls import path

from . import views

app_name = "devicedispenses"


urlpatterns = [
    path("devicedispenses/", views.DeviceDispenseListView.as_view()),
    path("devicedispenses/<int:pk>/", views.DeviceDispenseDetailView.as_view()),
]



"""Patients URL Configuration."""

from django.urls import path

from . import views

app_name = "patients"

urlpatterns = [
    path("patients/", views.PatientListView.as_view()),
    path("patients/<int:pk>/", views.PatientDetailView.as_view()),
]



"""Models for Conditions."""

from django.db import models

from dfhir.base.models import (
    BaseReference,
    CodeableConcept,
    Identifier,
    TimeStampedModel,
)


class ConditionReference(BaseReference):
    """Condition Reference model."""

    identifier = models.ForeignKey(
        Identifier,
        on_delete=models.DO_NOTHING,
        related_name="condition_reference_identifier",
        null=True,
    )
    condition = models.ForeignKey(
        "Condition",
        on_delete=models.DO_NOTHING,
        related_name="condition_reference",
        null=True,
    )


class ConditionCodeableReference(TimeStampedModel):
    """Condition Codeable Reference model."""

    concept = models.ForeignKey(
        CodeableConcept,
        on_delete=models.DO_NOTHING,
        related_name="condition_concept",
        null=True,
    )
    reference = models.ForeignKey(
        ConditionReference,
        on_delete=models.DO_NOTHING,
        related_name="condition_codeable_reference",
        null=True,
    )


class ConditionStageAssessmentReference(BaseReference):
    """condition stage assessment reference model."""

    identifier = models.ForeignKey(
        Identifier,
        on_delete=models.DO_NOTHING,
        related_name="condition_stage_assessment_reference_identifier",
        null=True,
    )
    clinical_impression = models.ForeignKey(
        "clinicalimpressions.ClinicalImpression",
        on_delete=models.DO_NOTHING,
        related_name="condition_stage_assessment_reference_clinical_impression",
        null=True,
    )
    diagnostic_report = models.ForeignKey(
        "diagnosticreports.DiagnosticReport",
        on_delete=models.DO_NOTHING,
        related_name="condition_stage_assessment_reference_diagnostic_report",
        null=True,
    )
    observation = models.ForeignKey(
        "observations.Observation",
        on_delete=models.DO_NOTHING,
        related_name="condition_stage_assessment_reference_observation",
        null=True,
    )


class ConditionStage(TimeStampedModel):
    """Condition Stage model."""

    summary = models.ForeignKey(
        CodeableConcept,
        on_delete=models.DO_NOTHING,
        related_name="condition_stage_summary",
        null=True,
    )
    assessment = models.ManyToManyField(
        ConditionStageAssessmentReference,
        blank=True,
        related_name="condition_stage_assessment",
    )
    type = models.ForeignKey(
        CodeableConcept,
        on_delete=models.DO_NOTHING,
        related_name="condition_stage_type",
        null=True,
    )


class ConditionRecorderReference(BaseReference):
    """condition recorder reference model."""

    identifier = models.ForeignKey(
        Identifier,
        on_delete=models.DO_NOTHING,
        related_name="condition_recorder_reference_identifier",
        null=True,
    )
    practitioner = models.ForeignKey(
        "practitioners.Practitioner",
        on_delete=models.DO_NOTHING,
        related_name="condition_recorder_reference_practitioner",
        null=True,
    )
    practitioner_role = models.ForeignKey(
        "practitionerroles.PractitionerRole",
        on_delete=models.DO_NOTHING,
        related_name="condition_recorder_reference_practitioner_role",
        null=True,
    )
    patient = models.ForeignKey(
        "patients.Patient",
        on_delete=models.DO_NOTHING,
        related_name="condition_recorder_reference_patient",
        null=True,
    )
    related_person = models.ForeignKey(
        "relatedpersons.RelatedPerson",
        on_delete=models.DO_NOTHING,
        related_name="condition_recorder_reference_related_person",
        null=True,
    )


class ConditionAsserterReference(BaseReference):
    """condition asserter reference model."""

    identifier = models.ForeignKey(
        Identifier,
        on_delete=models.DO_NOTHING,
        related_name="condition_asserter_reference_identifier",
        null=True,
    )
    practitioner = models.ForeignKey(
        "practitioners.Practitioner",
        on_delete=models.DO_NOTHING,
        related_name="condition_asserter_reference_practitioner",
        null=True,
    )
    practitioner_role = models.ForeignKey(
        "practitionerroles.PractitionerRole",
        on_delete=models.DO_NOTHING,
        related_name="condition_asserter_reference_practitioner_role",
        null=True,
    )
    patient = models.ForeignKey(
        "patients.Patient",
        on_delete=models.DO_NOTHING,
        related_name="condition_asserter_reference_patient",
        null=True,
    )
    related_person = models.ForeignKey(
        "relatedpersons.RelatedPerson",
        on_delete=models.DO_NOTHING,
        related_name="condition_asserter_reference_related_person",
        null=True,
    )
    device = models.ForeignKey(
        "devices.Device",
        on_delete=models.DO_NOTHING,
        related_name="condition_asserter_reference_device",
        null=True,
    )


class Condition(TimeStampedModel):
    """Condition model."""

    identifier = models.ManyToManyField(
        Identifier,
        related_name="condition_identifier",
        blank=True,
    )
    clinical_status = models.ForeignKey(
        CodeableConcept,
        on_delete=models.DO_NOTHING,
        related_name="condition_clinical_status",
        null=True,
    )
    verification_status = models.ForeignKey(
        CodeableConcept,
        on_delete=models.DO_NOTHING,
        related_name="condition_verification_status",
        null=True,
    )
    category = models.ManyToManyField(
        CodeableConcept,
        related_name="condition_category",
        blank=True,
    )
    severity = models.ForeignKey(
        CodeableConcept,
        on_delete=models.DO_NOTHING,
        related_name="condition_severity",
        null=True,
    )
    code = models.ForeignKey(
        CodeableConcept,
        on_delete=models.DO_NOTHING,
        related_name="condition_code",
        null=True,
    )
    body_site = models.ManyToManyField(
        CodeableConcept,
        related_name="condition_body_site",
        blank=True,
    )
    body_structure = models.ForeignKey(
        "bodystructures.BodyStructure",
        on_delete=models.DO_NOTHING,
        null=True,
        related_name="condition_body_structure",
    )
    subject = models.ForeignKey(
        "patients.PatientGroupReference",
        on_delete=models.DO_NOTHING,
        related_name="condition_subject",
        null=True,
    )
    encounter = models.ForeignKey(
        "encounters.EncounterReference",
        on_delete=models.DO_NOTHING,
        related_name="condition_encounter",
        null=True,
    )
    onset_date_time = models.DateTimeField(null=True)
    onset_age = models.ForeignKey(
        "base.Age",
        on_delete=models.DO_NOTHING,
        related_name="condition_onset_age",
        null=True,
    )
    onset_period = models.ForeignKey(
        "base.Period",
        on_delete=models.DO_NOTHING,
        related_name="condition_onset_period",
        null=True,
    )
    onset_range = models.ForeignKey(
        "base.Range",
        on_delete=models.DO_NOTHING,
        related_name="condition_onset_range",
        null=True,
    )
    onset_string = models.CharField(max_length=255, null=True)
    abatement_date_time = models.DateTimeField(null=True)
    abatement_age = models.ForeignKey(
        "base.Age",
        on_delete=models.DO_NOTHING,
        related_name="condition_abatement_age",
        null=True,
    )
    abatement_period = models.ForeignKey(
        "base.Period",
        on_delete=models.DO_NOTHING,
        related_name="condition_abatement_period",
        null=True,
    )
    abatement_range = models.ForeignKey(
        "base.Range",
        on_delete=models.DO_NOTHING,
        related_name="condition_abatement_range",
        null=True,
    )
    abatement_string = models.CharField(max_length=255, null=True)
    recorded_date = models.DateTimeField(null=True)
    recorder = models.ForeignKey(
        ConditionRecorderReference,
        on_delete=models.DO_NOTHING,
        related_name="condition_recorder",
        null=True,
    )
    asserter = models.ForeignKey(
        ConditionAsserterReference,
        on_delete=models.DO_NOTHING,
        related_name="condition_asserter",
        null=True,
    )
    stage = models.ManyToManyField(
        ConditionStage, related_name="condition_stage", blank=True
    )
    evidence = models.ManyToManyField(
        "base.CodeableReference", related_name="condition_evidence", blank=True
    )
    note = models.ManyToManyField(
        "base.Annotation", related_name="condition_note", blank=True
    )


class ConditionObservationReference(BaseReference):
    """Conditions Observation Reference model."""

    identifier = models.ForeignKey(
        Identifier,
        on_delete=models.DO_NOTHING,
        related_name="condition_observation_reference_identifier",
        null=True,
    )
    observation = models.ForeignKey(
        "observations.Observation",
        on_delete=models.DO_NOTHING,
        related_name="condition_observation_reference_observation",
        null=True,
    )
    condition = models.ForeignKey(
        Condition,
        on_delete=models.DO_NOTHING,
        related_name="condition_observation_reference_condition",
        null=True,
    )


class ConditionObservationCodeableReference(TimeStampedModel):
    """Condition Observation Codeable Reference model."""

    reference = models.ForeignKey(
        ConditionObservationReference,
        on_delete=models.DO_NOTHING,
        related_name="condition_observation_codeable_reference",
        null=True,
    )
    concept = models.ForeignKey(
        CodeableConcept,
        on_delete=models.DO_NOTHING,
        related_name="condition_observation_concept",
        null=True,
    )


class ConditionAllergyIntoleranceReference(BaseReference):
    """Condition Allergy Intolerance Reference model."""

    identifier = models.ForeignKey(
        Identifier,
        on_delete=models.DO_NOTHING,
        related_name="condition_allergy_intolerance_reference_identifier",
        null=True,
    )
    condition = models.ForeignKey(
        Condition,
        on_delete=models.DO_NOTHING,
        related_name="condition_allergy_intolerance_reference_condition",
        null=True,
    )
    allergy_intolerance = models.ForeignKey(
        "allergyintolerances.AllergyIntolerance",
        on_delete=models.DO_NOTHING,
        related_name="condition_allergy_intolerance_reference_allergy_intolerance",
        null=True,
    )



# Generated by Django 5.2 on 2025-05-05 14:45

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('bodystructures', '0002_initial'),
        ('specimens', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='specimencollection',
            name='body_site',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='specimen_collections_body_site', to='bodystructures.bodystructurecodeablereference'),
        ),
    ]



"""Payment Notices serializers."""

from dfhir.base.serializers import (
    BaseReferenceModelSerializer,
    BaseWritableNestedModelSerializer,
    CodeableConceptSerializer,
    IdentifierSerializer,
    MoneySerializer,
    OrganizationReferenceSerializer,
)

from ..paymentreconciliations.serializers import (
    PaymentReconciliationReferenceSerializer,
)
from .models import (
    PaymentNotice,
    PaymentNoticePayeeReference,
    PaymentNoticeReporterReference,
    PaymentNoticeRequestReference,
    PaymentNoticeResponseReference,
)


class PaymentNoticeReporterReferenceSerializer(BaseReferenceModelSerializer):
    """Payment Notice Reporter Reference Serializer."""

    identifier = IdentifierSerializer(required=False)

    class Meta:
        """Meta class."""

        model = PaymentNoticeReporterReference
        exclude = ["created_at", "updated_at"]


class PaymentNoticePayeeReferenceSerializer(BaseReferenceModelSerializer):
    """Payment Notice Payee Reference Serializer."""

    identifier = IdentifierSerializer(required=False)

    class Meta:
        """Meta class."""

        model = PaymentNoticePayeeReference
        exclude = ["created_at", "updated_at"]


class PaymentNoticeRequestReferenceSerializer(BaseReferenceModelSerializer):
    """Payment Notice Request Reference Serializer."""

    identifier = IdentifierSerializer(required=False)

    class Meta:
        """Meta class."""

        model = PaymentNoticeRequestReference
        exclude = ["created_at", "updated_at"]


class PaymentNoticeResponseReferenceSerializer(BaseReferenceModelSerializer):
    """Payment Notice Response Reference Serializer."""

    identifier = IdentifierSerializer(required=False)

    class Meta:
        """Meta class."""

        model = PaymentNoticeResponseReference
        exclude = ["created_at", "updated_at"]


class PaymentNoticeSerializer(BaseWritableNestedModelSerializer):
    """Payment Notice Serializer."""

    identifier = IdentifierSerializer(many=True, required=False)
    request = PaymentNoticeRequestReferenceSerializer(many=False, required=False)
    response = PaymentNoticeResponseReferenceSerializer(many=False, required=False)
    reporter = PaymentNoticeReporterReferenceSerializer(many=False, required=False)
    payment = PaymentReconciliationReferenceSerializer(many=False, required=False)
    payee = PaymentNoticePayeeReferenceSerializer(many=False, required=False)
    recipient = OrganizationReferenceSerializer(many=False, required=False)
    amount = MoneySerializer(many=False, required=False)
    payment_status = CodeableConceptSerializer(many=False, required=False)

    class Meta:
        """Meta class."""

        model = PaymentNotice
        exclude = ["created_at", "updated_at"]



"""nutrition order serializers."""

from drf_writable_nested.serializers import WritableNestedModelSerializer

from dfhir.allergyintolerances.serializers import AllergyIntoleranceReferenceSerializer
from dfhir.base.serializers import (
    AnnotationSerializer,
    BaseReferenceModelSerializer,
    BaseWritableNestedModelSerializer,
    CodeableConceptSerializer,
    IdentifierSerializer,
    QuantitySerializer,
    RatioSerializer,
    ReferenceSerializer,
    TimingSerializer,
)
from dfhir.devicedefinitions.serializers import (
    DeviceDefinitionCodeableReferenceSerializer,
)
from dfhir.encounters.serializers import EncounterReferenceSerializer
from dfhir.nutritionorders.models import (
    NutritionOrder,
    NutritionOrderAdditive,
    NutritionOrderBasedOnReference,
    NutritionOrderCodeableReference,
    NutritionOrderEnteralFormula,
    NutritionOrderEnteralFormulaAdministration,
    NutritionOrderOralDiet,
    NutritionOrderOralDietNutrient,
    NutritionOrderOralDietTexture,
    NutritionOrderPerformerReference,
    NutritionOrderReference,
    NutritionOrderSchedule,
    NutritionOrderSupplement,
)
from dfhir.nutritionproducts.serializers import (
    NutritionProductCodeableReferenceSerializer,
)
from dfhir.patients.serializers import PatientGroupReferenceSerializer
from dfhir.practitioners.serializers import (
    PractitionerPractitionerRoleReferenceSerializer,
)


class NutritionOrderReferenceSerializer(BaseReferenceModelSerializer):
    """nutrition order reference serializer."""

    identifier = IdentifierSerializer(required=False)

    class Meta:
        """Meta."""

        model = NutritionOrderReference
        exclude = ["created_at", "updated_at"]


class NutritionOrderCodeableReferenceSerializer(WritableNestedModelSerializer):
    """nutrition order codeable reference serializer."""

    concept = CodeableConceptSerializer(required=False)
    reference = NutritionOrderReferenceSerializer(required=False)

    class Meta:
        """Meta."""

        model = NutritionOrderCodeableReference
        exclude = ["created_at", "updated_at"]


class NutritionOrderScheduleSerializer(WritableNestedModelSerializer):
    """nutrition order schedule serializer."""

    timing = TimingSerializer(required=False, many=True)
    as_needed_for = CodeableConceptSerializer(required=False)

    class Meta:
        """Meta."""

        model = NutritionOrderSchedule
        exclude = ["created_at", "updated_at"]


class NutritionOrderOralDietNutrientSerializer(WritableNestedModelSerializer):
    """nutrition order oral diet nutrient serializer."""

    modifier = CodeableConceptSerializer(required=False)
    amount = QuantitySerializer(required=False)

    class Meta:
        """Meta."""

        model = NutritionOrderOralDietNutrient
        exclude = ["created_at", "updated_at"]


class NutritionOrderOralDietTextureSerializer(WritableNestedModelSerializer):
    """nutrition order oral diet texture serializer."""

    modifier = CodeableConceptSerializer(required=False)
    type = CodeableConceptSerializer(required=False)

    class Meta:
        """Meta."""

        model = NutritionOrderOralDietTexture
        exclude = ["created_at", "updated_at"]


class NutritionOrderOralDietSerializer(WritableNestedModelSerializer):
    """nutrition order oral diet serializer."""

    type = CodeableConceptSerializer(required=False, many=True)
    schedule = NutritionOrderScheduleSerializer(required=False)
    nutrient = NutritionOrderOralDietNutrientSerializer(required=False, many=True)
    texture = NutritionOrderOralDietTextureSerializer(required=False, many=True)
    caloric_density = QuantitySerializer(required=False)

    class Meta:
        """Meta."""

        model = NutritionOrderOralDiet
        exclude = ["created_at", "updated_at"]


class NutritionOrderSupplementSerializer(WritableNestedModelSerializer):
    """nutrition order supplement serializer."""

    type = NutritionProductCodeableReferenceSerializer(required=False)
    schedule = NutritionOrderScheduleSerializer(required=False, many=True)
    quantity = QuantitySerializer(required=False)
    caloric_density = QuantitySerializer(required=False)

    class Meta:
        """Meta."""

        model = NutritionOrderSupplement
        exclude = ["created_at", "updated_at"]


class NutritionOrderEnteralFormulaAdministrationSerializer(
    WritableNestedModelSerializer
):
    """nutrition order enteral formula administration serializer."""

    schedule = NutritionOrderScheduleSerializer(required=False)
    quantity = QuantitySerializer(required=False)
    rate_quantity = QuantitySerializer(required=False)
    rate_ratio = RatioSerializer(required=False)

    class Meta:
        """Meta."""

        model = NutritionOrderEnteralFormulaAdministration
        exclude = ["created_at", "updated_at"]


class NutritionOrderEnteralFormulaSerializer(WritableNestedModelSerializer):
    """nutrition order enteral formula serializer."""

    type = NutritionProductCodeableReferenceSerializer(required=False)
    delivery_device = DeviceDefinitionCodeableReferenceSerializer(
        required=False, many=True
    )
    caloric_density = QuantitySerializer(required=False)
    route_of_administration = CodeableConceptSerializer(required=False, many=True)
    administration = NutritionOrderEnteralFormulaAdministrationSerializer(
        required=False, many=True
    )
    max_volume_administer = QuantitySerializer(required=False)

    class Meta:
        """Meta."""

        model = NutritionOrderEnteralFormula
        exclude = ["created_at", "updated_at"]


class NutritionOrderAdditiveSerializer(WritableNestedModelSerializer):
    """nutrition order additive serializer."""

    modular_type = NutritionProductCodeableReferenceSerializer(required=False)
    quantity = QuantitySerializer(required=False)

    class Meta:
        """Meta."""

        model = NutritionOrderAdditive
        exclude = ["created_at", "updated_at"]


class NutritionOrderBasedOnReferenceSerializer(BaseReferenceModelSerializer):
    """nutrition order based on reference serializer."""

    identifier = IdentifierSerializer(required=False)

    class Meta:
        """Meta."""

        model = NutritionOrderBasedOnReference
        exclude = ["created_at", "updated_at"]


class NutritionOrderPerformerReferenceSerializer(BaseReferenceModelSerializer):
    """nutrition order performer reference serializer."""

    identifier = IdentifierSerializer(required=False)

    class Meta:
        """Meta."""

        model = NutritionOrderPerformerReference
        exclude = ["created_at", "updated_at"]


class NutritionOrderSerializer(BaseWritableNestedModelSerializer):
    """nutrition order serializer."""

    identifier = IdentifierSerializer(required=False, many=True)
    # TODO: instantiates_canonical = NutritionOrderBasedOnReferenceSerializer(required=False, many=True)
    based_on = NutritionOrderBasedOnReferenceSerializer(required=False, many=True)
    group_identifier = IdentifierSerializer(required=False)
    subject = PatientGroupReferenceSerializer(required=False)
    encounter = EncounterReferenceSerializer(required=False)
    supporting_information = ReferenceSerializer(required=False, many=True)
    orderer = PractitionerPractitionerRoleReferenceSerializer(required=False)
    performer = NutritionOrderPerformerReferenceSerializer(required=False, many=True)
    allergy_intolerance = AllergyIntoleranceReferenceSerializer(
        required=False, many=True
    )
    food_preference_modifier = CodeableConceptSerializer(required=False, many=True)
    exclude_food_modifier = CodeableConceptSerializer(required=False, many=True)
    oral_diet = NutritionOrderOralDietSerializer(required=False)
    supplement = NutritionOrderSupplementSerializer(required=False, many=True)
    enteral_formula = NutritionOrderEnteralFormulaSerializer(required=False)
    additive = NutritionOrderAdditiveSerializer(required=False, many=True)
    note = AnnotationSerializer(required=False, many=True)

    class Meta:
        """Meta."""

        model = NutritionOrder
        exclude = ["created_at", "updated_at"]



# Generated by Django 5.2 on 2025-04-23 12:46

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('inventoryreports', '0001_initial'),
        ('patients', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='inventoryreportreporterreference',
            name='patient',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='inventory_report_reporter_reference_patient', to='patients.patient'),
        ),
    ]



"""inventory item views."""

from django.http import Http404
from drf_spectacular.utils import extend_schema
from rest_framework import status
from rest_framework.permissions import AllowAny
from rest_framework.response import Response
from rest_framework.views import APIView

from dfhir.inventoryitems.models import InventoryItem
from dfhir.inventoryitems.serializers import InventoryItemSerializer


class InventoryItemListView(APIView):
    """inventory item list view."""

    permission_classes = [AllowAny]

    @extend_schema(responses={200: InventoryItemSerializer(many=True)})
    def get(self, request):
        """List inventory items."""
        queryset = InventoryItem.objects.all()
        serializer = InventoryItemSerializer(queryset, many=True)
        return Response(serializer.data, status=status.HTTP_200_OK)

    @extend_schema(
        request=InventoryItemSerializer, responses={201: InventoryItemSerializer}
    )
    def post(self, request):
        """Create inventory item."""
        serializer = InventoryItemSerializer(data=request.data)
        serializer.is_valid(raise_exception=True)
        serializer.save()
        return Response(serializer.data, status=status.HTTP_201_CREATED)


class InventoryItemDetailView(APIView):
    """inventory item detail view."""

    permission_classes = [AllowAny]

    def get_object(self, pk):
        """Get inventory item object."""
        try:
            return InventoryItem.objects.get(pk=pk)
        except InventoryItem.DoesNotExist as err:
            raise Http404 from err

    @extend_schema(responses={200: InventoryItemSerializer})
    def get(self, request, pk=None):
        """Retrieve inventory item."""
        inventory_item = self.get_object(pk)
        serializer = InventoryItemSerializer(inventory_item)
        return Response(serializer.data, status=status.HTTP_200_OK)

    @extend_schema(responses={200: InventoryItemSerializer})
    def patch(self, request, pk=None):
        """Update inventory item."""
        inventory_item = self.get_object(pk)
        serializer = InventoryItemSerializer(
            inventory_item, data=request.data, partial=True
        )
        serializer.is_valid(raise_exception=True)
        serializer.save()
        return Response(serializer.data, status=status.HTTP_200_OK)

    def delete(self, request, pk=None):
        """Delete inventory item."""
        inventory_item = self.get_object(pk)
        inventory_item.delete()
        return Response(status=status.HTTP_204_NO_CONTENT)



"""diagnosticreports URL Configuration."""

from django.urls import path

from . import views

app_name = "diagnosticreports"

urlpatterns = [
    path(
        "diagnosticreports/", views.DiagnosticReportListView.as_view(), name="list_view"
    ),
    path(
        "diagnosticreports/<int:pk>/",
        views.DiagnosticReportDetailView.as_view(),
        name="detail_view",
    ),
    path(
        "diagnosticreports/codes/",
        views.DiagnosticReportCodeListView.as_view(),
        name="codes_list_view",
    ),
    path(
        "diagnosticreports/categories/",
        views.DiagnosticCategoryListView.as_view(),
        name="categories_list_view",
    ),
    path(
        "diagnosticreports/conclusioncodes/",
        views.ConclusionCodeListView.as_view(),
        name="conclusion_list_view",
    ),
]



# Generated by Django 5.2 on 2025-04-23 12:46

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('base', '0003_initial'),
        ('claimresponses', '0002_initial'),
        ('contracts', '0001_initial'),
        ('coverages', '0001_initial'),
        ('organizations', '0001_initial'),
        ('patients', '0001_initial'),
        ('relatedpersons', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='coverage',
            name='beneficiary',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='coverage_beneficiary', to='patients.patientreference'),
        ),
        migrations.AddField(
            model_name='coverage',
            name='contract',
            field=models.ManyToManyField(blank=True, related_name='coverage_contract', to='contracts.contractreference'),
        ),
        migrations.AddField(
            model_name='coverage',
            name='identifier',
            field=models.ManyToManyField(blank=True, related_name='coverage_identifier', to='base.identifier'),
        ),
        migrations.AddField(
            model_name='coverage',
            name='insurer',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='coverage_insurer', to='base.organizationreference'),
        ),
        migrations.AddField(
            model_name='coverage',
            name='period',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='coverage_period', to='base.period'),
        ),
        migrations.AddField(
            model_name='coverage',
            name='relationship',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='coverage_relationship', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='coverage',
            name='subscriber',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='coverage_subscriber', to='patients.patientrelatedpersonreference'),
        ),
        migrations.AddField(
            model_name='coverage',
            name='subscriber_identifier',
            field=models.ManyToManyField(blank=True, related_name='coverage_subscriber_identifier', to='base.identifier'),
        ),
        migrations.AddField(
            model_name='coverage',
            name='type',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='coverage_type', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='coverageclaimresponsereference',
            name='claim_response',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='coverage_claim_response_reference_claim_response', to='claimresponses.claimresponse'),
        ),
        migrations.AddField(
            model_name='coverageclaimresponsereference',
            name='coverage',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='coverage_claim_response_reference_coverage', to='coverages.coverage'),
        ),
        migrations.AddField(
            model_name='coverageclaimresponsereference',
            name='identifier',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='coverage_claim_response_reference_identifier', to='base.identifier'),
        ),
        migrations.AddField(
            model_name='coverageclass',
            name='type',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='coverage_class_type', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='coverageclass',
            name='value',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='coverage_class_value', to='base.identifier'),
        ),
        migrations.AddField(
            model_name='coverage',
            name='klass',
            field=models.ManyToManyField(blank=True, related_name='coverage_class', to='coverages.coverageclass'),
        ),
        migrations.AddField(
            model_name='coveragecosttobeneficiary',
            name='category',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='coverage_cost_to_beneficiary_category', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='coveragecosttobeneficiary',
            name='network',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='coverage_cost_to_beneficiary_network', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='coveragecosttobeneficiary',
            name='term',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='coverage_cost_to_beneficiary_term', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='coveragecosttobeneficiary',
            name='type',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='coverage_cost_to_beneficiary_type', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='coveragecosttobeneficiary',
            name='unit',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='coverage_cost_to_beneficiary_unit', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='coveragecosttobeneficiary',
            name='value_money',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='coverage_cost_to_beneficiary_value_money', to='base.money'),
        ),
        migrations.AddField(
            model_name='coveragecosttobeneficiary',
            name='value_quantity',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='coverage_cost_to_beneficiary_value_quantity', to='base.simplequantity'),
        ),
        migrations.AddField(
            model_name='coverage',
            name='cost_to_beneficiary',
            field=models.ManyToManyField(blank=True, related_name='coverage_cost_to_beneficiary', to='coverages.coveragecosttobeneficiary'),
        ),
        migrations.AddField(
            model_name='coveragecosttobeneficiaryexception',
            name='period',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='coverage_cost_to_beneficiary_exception_period', to='base.period'),
        ),
        migrations.AddField(
            model_name='coveragecosttobeneficiaryexception',
            name='type',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='coverage_cost_to_beneficiary_exception_type', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='coveragecosttobeneficiary',
            name='exception',
            field=models.ManyToManyField(blank=True, related_name='coverage_cost_to_beneficiary_exception', to='coverages.coveragecosttobeneficiaryexception'),
        ),
        migrations.AddField(
            model_name='coverage',
            name='payment_by',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='coverage_payment_by', to='coverages.coveragepaymentby'),
        ),
        migrations.AddField(
            model_name='coveragepaymentbypartyreference',
            name='identifier',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='coverage_by_reference_identifier', to='base.identifier'),
        ),
        migrations.AddField(
            model_name='coveragepaymentbypartyreference',
            name='organization',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='coverage_by_reference_organization', to='organizations.organization'),
        ),
        migrations.AddField(
            model_name='coveragepaymentbypartyreference',
            name='patient',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='coverage_by_reference_patient', to='patients.patient'),
        ),
        migrations.AddField(
            model_name='coveragepaymentbypartyreference',
            name='related_person',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='coverage_by_reference_related_person', to='relatedpersons.relatedperson'),
        ),
        migrations.AddField(
            model_name='coveragepaymentby',
            name='party',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='coverage_payment_by_party', to='coverages.coveragepaymentbypartyreference'),
        ),
        migrations.AddField(
            model_name='coveragepolicyholderreference',
            name='identifier',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='policy_holder_reference_identifier', to='base.identifier'),
        ),
        migrations.AddField(
            model_name='coveragepolicyholderreference',
            name='organization',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='policy_holder_reference_organization', to='organizations.organization'),
        ),
        migrations.AddField(
            model_name='coveragepolicyholderreference',
            name='patient',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='policy_holder_reference_patient', to='patients.patient'),
        ),
        migrations.AddField(
            model_name='coveragepolicyholderreference',
            name='related_person',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='policy_holder_reference_related_person', to='relatedpersons.relatedperson'),
        ),
        migrations.AddField(
            model_name='coverage',
            name='policy_holder',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='coverage_policy_holder', to='coverages.coveragepolicyholderreference'),
        ),
        migrations.AddField(
            model_name='coveragereference',
            name='coverage',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='coverage_reference_coverage', to='coverages.coverage'),
        ),
        migrations.AddField(
            model_name='coveragereference',
            name='identifier',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='coverage_reference_identifier', to='base.identifier'),
        ),
    ]



"""Groups views."""

from drf_spectacular.utils import extend_schema
from rest_framework import status
from rest_framework.permissions import AllowAny
from rest_framework.response import Response
from rest_framework.views import APIView

from .models import Group
from .serializers import GroupSerializer


class GroupListView(APIView):
    """Group list view."""

    serializer = GroupSerializer
    permission_classes = [AllowAny]

    @extend_schema(responses={200, GroupSerializer(many=True)})
    def get(self, request):
        """Get all groups."""
        groups = Group.objects.all()
        serializer = self.serializer(groups, many=True)
        return Response(serializer.data)

    @extend_schema(
        request=GroupSerializer,
        responses={201, GroupSerializer},
    )
    def post(self, request):
        """Create a new group."""
        serializer = self.serializer(data=request.data)
        if serializer.is_valid():
            serializer.save()
            return Response(serializer.data, status=status.HTTP_201_CREATED)
        return Response(serializer.errors, status=status.HTTP_400_BAD_REQUEST)


class GroupDetailView(APIView):
    """Group detail view."""

    serializer = GroupSerializer

    def get_object(self, pk=None):
        """Get group object."""
        try:
            return Group.objects.get(pk=pk)
        except Group.DoesNotExist:
            return Response(status=status.HTTP_404_NOT_FOUND)

    @extend_schema(responses={200, GroupSerializer})
    def get(self, request, pk):
        """Get group."""
        group = self.get_object(pk)
        serializer = self.serializer(group)
        return Response(serializer.data)

    @extend_schema(
        request=GroupSerializer,
        responses={200, GroupSerializer},
    )
    def put(self, request, pk):
        """Update group."""
        group = self.get_object(pk)
        serializer = self.serializer(group, data=request.data)
        if serializer.is_valid():
            serializer.save()
            return Response(serializer.data)
        return Response(serializer.errors, status=status.HTTP_400_BAD_REQUEST)

    @extend_schema(responses={204})
    def delete(self, request, pk):
        """Delete group."""
        group = self.get_object(pk)
        group.delete()
        return Response(status=status.HTTP_204_NO_CONTENT)



# Generated by Django 5.2 on 2025-04-23 12:46

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('base', '0002_initial'),
    ]

    operations = [
        migrations.CreateModel(
            name='CareTeamParticipant',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('updated_at', models.DateTimeField(auto_now=True)),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='CareTeamParticipantOnBehalfOfReference',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('updated_at', models.DateTimeField(auto_now=True)),
                ('reference', models.CharField(max_length=255, null=True)),
                ('type', models.CharField(max_length=255, null=True)),
                ('display', models.CharField(max_length=255, null=True)),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='CareTeamReference',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('updated_at', models.DateTimeField(auto_now=True)),
                ('reference', models.CharField(max_length=255, null=True)),
                ('type', models.CharField(max_length=255, null=True)),
                ('display', models.CharField(max_length=255, null=True)),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='CareTeam',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('updated_at', models.DateTimeField(auto_now=True)),
                ('status', models.CharField(choices=[('proposed', 'Proposed'), ('active', 'Active'), ('suspended', 'Suspended'), ('inactive', 'Inactive'), ('entered-in-error', 'Entered in Error')], max_length=255, null=True)),
                ('name', models.CharField(max_length=255, null=True)),
                ('category', models.ManyToManyField(blank=True, related_name='care_teams_category', to='base.codeableconcept')),
                ('identifier', models.ManyToManyField(blank=True, related_name='care_teams_identifier', to='base.identifier')),
                ('managing_organization', models.ManyToManyField(blank=True, related_name='care_teams_managing_organization', to='base.organizationreference')),
                ('note', models.ManyToManyField(blank=True, related_name='care_teams_note', to='base.annotation')),
                ('period', models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='care_teams_period', to='base.period')),
            ],
            options={
                'abstract': False,
            },
        ),
    ]



"""observation definitions views."""

from django.http import Http404
from drf_spectacular.utils import extend_schema
from rest_framework import status
from rest_framework.permissions import AllowAny
from rest_framework.response import Response
from rest_framework.views import APIView

from dfhir.observationdefinitions.models import ObservationDefinition
from dfhir.observationdefinitions.serializers import ObservationDefinitionSerializer


class ObservationDefinitionListView(APIView):
    """observation definition list view."""

    permission_classes = [AllowAny]

    @extend_schema(
        responses={200: ObservationDefinitionSerializer(many=True)},
    )
    def get(self, request):
        """Get observation definitions."""
        queryset = ObservationDefinition.objects.all()
        serializer = ObservationDefinitionSerializer(queryset, many=True)
        return Response(serializer.data, status=status.HTTP_200_OK)

    @extend_schema(
        request=ObservationDefinitionSerializer,
        responses={201: ObservationDefinitionSerializer},
    )
    def post(self, request):
        """Create observation definition."""
        serializer = ObservationDefinitionSerializer(data=request.data)
        serializer.is_valid(raise_exception=True)
        serializer.save()
        return Response(serializer.data, status=status.HTTP_201_CREATED)


class ObservationDefinitionDetailView(APIView):
    """observation definition detail view."""

    permission_classes = [AllowAny]

    def get_object(self, pk):
        """Get observation definition object."""
        try:
            return ObservationDefinition.objects.get(pk=pk)
        except ObservationDefinition.DoesNotExist as err:
            raise Http404 from err

    @extend_schema(responses={200: ObservationDefinitionSerializer})
    def get(self, request, pk=None):
        """Get observation definition."""
        observation_definition = self.get_object(pk)
        serializer = ObservationDefinitionSerializer(observation_definition)
        return Response(serializer.data, status=status.HTTP_200_OK)

    @extend_schema(responses={200: ObservationDefinitionSerializer})
    def patch(self, request, pk=None):
        """Update observation definition."""
        observation_definition = self.get_object(pk)
        serializer = ObservationDefinitionSerializer(
            observation_definition, data=request.data, partial=True
        )
        serializer.is_valid(raise_exception=True)
        serializer.save()
        return Response(serializer.data, status=status.HTTP_200_OK)

    def delete(self, request, pk=None):
        """Delete observation definition."""
        observation_definition = self.get_object(pk)
        observation_definition.delete()
        return Response(status=status.HTTP_204_NO_CONTENT)



"""Persons URL Configuration."""

from django.urls import path

from . import views

app_name = "persons"

urlpatterns = [
    path("persons/", views.PersonListView.as_view()),
    path("persons/<int:pk>/", views.PersonDetailView.as_view()),
]



# Generated by Django 5.2 on 2025-04-23 12:46

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('base', '0005_initial'),
        ('organizations', '0001_initial'),
        ('paymentnotices', '0001_initial'),
        ('practitionerroles', '0001_initial'),
        ('practitioners', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='paymentnoticepayeereference',
            name='practitioner',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='payment_notice_payee_reference', to='practitioners.practitioner'),
        ),
        migrations.AddField(
            model_name='paymentnoticepayeereference',
            name='practitioner_role',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='payment_notice_payee_reference', to='practitionerroles.practitionerrole'),
        ),
        migrations.AddField(
            model_name='paymentnotice',
            name='payee',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='payment_notice', to='paymentnotices.paymentnoticepayeereference'),
        ),
        migrations.AddField(
            model_name='paymentnoticereporterreference',
            name='identifier',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='payment_notice_reporter_reference', to='base.identifier'),
        ),
        migrations.AddField(
            model_name='paymentnoticereporterreference',
            name='organization',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='payment_notice_reporter_reference', to='organizations.organization'),
        ),
        migrations.AddField(
            model_name='paymentnoticereporterreference',
            name='practitioner',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='payment_notice_reporter_reference', to='practitioners.practitioner'),
        ),
        migrations.AddField(
            model_name='paymentnoticereporterreference',
            name='practitioner_role',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='payment_notice_reporter_reference', to='practitionerroles.practitionerrole'),
        ),
        migrations.AddField(
            model_name='paymentnotice',
            name='reporter',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='payment_notice', to='paymentnotices.paymentnoticereporterreference'),
        ),
        migrations.AddField(
            model_name='paymentnoticerequestreference',
            name='identifier',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='payment_notice_request_reference', to='base.identifier'),
        ),
        migrations.AddField(
            model_name='paymentnotice',
            name='request',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='payment_notice', to='paymentnotices.paymentnoticerequestreference'),
        ),
        migrations.AddField(
            model_name='paymentnoticeresponsereference',
            name='identifier',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='payment_notice_response_reference', to='base.identifier'),
        ),
        migrations.AddField(
            model_name='paymentnotice',
            name='response',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='payment_notice', to='paymentnotices.paymentnoticeresponsereference'),
        ),
    ]



"""Patient signals."""

from django.db.models.signals import post_save
from django.dispatch import receiver

from .models import Patient


@receiver(post_save, sender=Patient)
def send_patient_email(sender, instance, created, **kwargs):
    """Send patient invite via email."""
    # if created and not (
    #     Invite.objects.filter(email__iexact=instance.email, patient=instance)
    #     .order_by("created_at")
    #     .last()
    # ):
    #     invitation = Invite.create(email=instance.email, patient=instance)
    #
    #     request = HttpRequest()
    #     request.META["HTTP_HOST"] = "localhost:3000"  # Replace with domain if available
    #     request.META["SERVER_NAME"] = "localhost"
    #     request.META["SERVER_PORT"] = "3000"
    #     invitation.send_invitation(
    #         request, first_name=instance.first_name, last_name=instance.last_name
    #     )



# Generated by Django 5.2 on 2025-04-23 12:46

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('base', '0005_initial'),
        ('careplans', '0004_initial'),
        ('nutritionorders', '0001_initial'),
        ('nutritionproducts', '0001_initial'),
        ('patients', '0002_initial'),
        ('practitioners', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='nutritionorder',
            name='orderer',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='nutrition_order_orderer', to='practitioners.practitionerpractitionerrolereference'),
        ),
        migrations.AddField(
            model_name='nutritionorder',
            name='subject',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='nutrition_order_subject', to='patients.patientgroupreference'),
        ),
        migrations.AddField(
            model_name='nutritionorder',
            name='supporting_information',
            field=models.ManyToManyField(blank=True, related_name='nutrition_order_supporting_information', to='base.reference'),
        ),
        migrations.AddField(
            model_name='nutritionorderadditive',
            name='modular_type',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='nutrition_order_additive_modular_type', to='nutritionproducts.nutritionproductcodeablereference'),
        ),
        migrations.AddField(
            model_name='nutritionorderadditive',
            name='quantity',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='nutrition_order_additive_quantity', to='base.quantity'),
        ),
        migrations.AddField(
            model_name='nutritionorder',
            name='additive',
            field=models.ManyToManyField(blank=True, related_name='nutrition_order_additive', to='nutritionorders.nutritionorderadditive'),
        ),
        migrations.AddField(
            model_name='nutritionorderbasedonreference',
            name='care_plan',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='nutrition_order_based_on_reference_care_plan', to='careplans.careplan'),
        ),
        migrations.AddField(
            model_name='nutritionorderbasedonreference',
            name='identifier',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='nutrition_order_based_on_reference_identifier', to='base.identifier'),
        ),
        migrations.AddField(
            model_name='nutritionorderbasedonreference',
            name='nutrition_order',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='nutrition_order_based_on_reference_nutrition_order', to='nutritionorders.nutritionorder'),
        ),
    ]



# Generated by Django 5.2 on 2025-05-02 14:24

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('imagingselections', '0003_initial'),
        ('tasks', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='imagingselectionbasedonreference',
            name='task',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='image_selection_based_on_reference_task', to='tasks.task'),
        ),
    ]



"""Enrollment responses choices."""

from django.db import models
from django.utils.translation import gettext_lazy as _


class EnrollmentResponseStatus(models.TextChoices):
    """Enrollment response status choices."""

    ACTIVE = "active", _("Active")
    CANCELLED = "cancelled", _("Cancelled")
    DRAFT = "draft", _("Draft")
    ENTERED_IN_ERROR = "entered-in-error", _("Entered in Error")


class EnrollmentResponseOutcome(models.TextChoices):
    """Enrollment response outcome choices."""

    QUEUED = "queued", _("Queued")
    COMPLETE = "complete", _("Complete")
    ERROR = "error", _("Error")
    PARTIAL = "partial", _("Partial")



# Generated by Django 5.2 on 2025-04-23 12:46

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('base', '0005_initial'),
        ('clinicalimpressions', '0003_initial'),
        ('conditions', '0003_initial'),
        ('diagnosticreports', '0002_initial'),
        ('observations', '0002_initial'),
        ('patients', '0001_initial'),
        ('practitionerroles', '0001_initial'),
        ('practitioners', '0001_initial'),
        ('relatedpersons', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='conditionasserterreference',
            name='practitioner',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='condition_asserter_reference_practitioner', to='practitioners.practitioner'),
        ),
        migrations.AddField(
            model_name='conditionasserterreference',
            name='practitioner_role',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='condition_asserter_reference_practitioner_role', to='practitionerroles.practitionerrole'),
        ),
        migrations.AddField(
            model_name='conditionasserterreference',
            name='related_person',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='condition_asserter_reference_related_person', to='relatedpersons.relatedperson'),
        ),
        migrations.AddField(
            model_name='condition',
            name='asserter',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='condition_asserter', to='conditions.conditionasserterreference'),
        ),
        migrations.AddField(
            model_name='conditioncodeablereference',
            name='concept',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='condition_concept', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='conditionobservationcodeablereference',
            name='concept',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='condition_observation_concept', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='conditionobservationreference',
            name='condition',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='condition_observation_reference_condition', to='conditions.condition'),
        ),
        migrations.AddField(
            model_name='conditionobservationreference',
            name='identifier',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='condition_observation_reference_identifier', to='base.identifier'),
        ),
        migrations.AddField(
            model_name='conditionobservationreference',
            name='observation',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='condition_observation_reference_observation', to='observations.observation'),
        ),
        migrations.AddField(
            model_name='conditionobservationcodeablereference',
            name='reference',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='condition_observation_codeable_reference', to='conditions.conditionobservationreference'),
        ),
        migrations.AddField(
            model_name='conditionrecorderreference',
            name='identifier',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='condition_recorder_reference_identifier', to='base.identifier'),
        ),
        migrations.AddField(
            model_name='conditionrecorderreference',
            name='patient',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='condition_recorder_reference_patient', to='patients.patient'),
        ),
        migrations.AddField(
            model_name='conditionrecorderreference',
            name='practitioner',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='condition_recorder_reference_practitioner', to='practitioners.practitioner'),
        ),
        migrations.AddField(
            model_name='conditionrecorderreference',
            name='practitioner_role',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='condition_recorder_reference_practitioner_role', to='practitionerroles.practitionerrole'),
        ),
        migrations.AddField(
            model_name='conditionrecorderreference',
            name='related_person',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='condition_recorder_reference_related_person', to='relatedpersons.relatedperson'),
        ),
        migrations.AddField(
            model_name='condition',
            name='recorder',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='condition_recorder', to='conditions.conditionrecorderreference'),
        ),
        migrations.AddField(
            model_name='conditionreference',
            name='condition',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='condition_reference', to='conditions.condition'),
        ),
        migrations.AddField(
            model_name='conditionreference',
            name='identifier',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='condition_reference_identifier', to='base.identifier'),
        ),
        migrations.AddField(
            model_name='conditioncodeablereference',
            name='reference',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='condition_codeable_reference', to='conditions.conditionreference'),
        ),
        migrations.AddField(
            model_name='conditionstage',
            name='summary',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='condition_stage_summary', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='conditionstage',
            name='type',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='condition_stage_type', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='condition',
            name='stage',
            field=models.ManyToManyField(blank=True, related_name='condition_stage', to='conditions.conditionstage'),
        ),
        migrations.AddField(
            model_name='conditionstageassessmentreference',
            name='clinical_impression',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='condition_stage_assessment_reference_clinical_impression', to='clinicalimpressions.clinicalimpression'),
        ),
        migrations.AddField(
            model_name='conditionstageassessmentreference',
            name='diagnostic_report',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='condition_stage_assessment_reference_diagnostic_report', to='diagnosticreports.diagnosticreport'),
        ),
        migrations.AddField(
            model_name='conditionstageassessmentreference',
            name='identifier',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='condition_stage_assessment_reference_identifier', to='base.identifier'),
        ),
        migrations.AddField(
            model_name='conditionstageassessmentreference',
            name='observation',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='condition_stage_assessment_reference_observation', to='observations.observation'),
        ),
        migrations.AddField(
            model_name='conditionstage',
            name='assessment',
            field=models.ManyToManyField(blank=True, related_name='condition_stage_assessment', to='conditions.conditionstageassessmentreference'),
        ),
    ]
